@@ -1,39 +1,38 @@
 #ifndef UPDATEDIALOG_H
 #define UPDATEDIALOG_H
 
-#include <QAbstractButton>
-#include <QDialog>
-#include <QNetworkAccessManager>
-#include <QFile>
 #include "masterdialog.h"
 
 namespace Ui {
 class UpdateDialog;
 }
 
-class UpdateDialog : public MasterDialog
-{
+class QAbstractButton;
+class QNetworkReply;
+class QNetworkAccessManager;
+
+class UpdateDialog : public MasterDialog {
     Q_OBJECT
 
-public:
-    explicit UpdateDialog(
-            QWidget *parent = 0, QString changesHtml = "",
-            QString releaseUrl = "", QString releaseVersionString = "",
-            int releaseBuildNumber = 0);
+   public:
+    explicit UpdateDialog(QWidget *parent = nullptr,
+                          const QString &changesHtml = QString(),
+                          const QString &releaseUrl = QString(),
+                          const QString &releaseVersionString = QString());
     ~UpdateDialog();
     static bool isUpdateDialogOpen();
     int exec();
 
-public slots:
+   public slots:
     void show();
 
-private slots:
+   private slots:
     void dialogButtonClicked(QAbstractButton *button);
     void setIsUpdateDialogOpen(bool isOpen);
     void releaseDownloadProgress(qint64 bytesReceived, qint64 bytesTotal);
     void slotReplyFinished(QNetworkReply *reply);
 
-private:
+   private:
     Ui::UpdateDialog *ui;
     QString releaseUrl;
     QString releaseVersionString;
@@ -41,7 +40,7 @@ private:
     QPushButton *_updateButton;
 
     enum ButtonRole {
-        Unset,  // nothing was selected
+        Unset,    // nothing was selected
         Update,
         Download,
         Skip,
@@ -51,11 +50,13 @@ private:
 
     void closeEvent(QCloseEvent *event);
 
-    bool initializeUpdateProcess(QString filePath);
+    bool initializeUpdateProcess(const QString &filePath);
 
-    bool initializeWindowsUpdateProcess(QString filePath);
+    bool initializeLinuxUpdateProcess(const QString &filePath);
 
-    bool initializeMacOSUpdateProcess(QString releaseUrl);
+    bool initializeWindowsUpdateProcess(const QString &filePath);
+
+    bool initializeMacOSUpdateProcess(const QString &releaseUrl);
 };
 
-#endif // UPDATEDIALOG_H
+#endif    // UPDATEDIALOG_H
