@@ -2,45 +2,48 @@
  * Bookmark class
  */
 
-#include <utility>
 #include "bookmark.h"
-#include "notefolder.h"
+
 #include <QDebug>
-#include <QRegularExpression>
-#include <QRegularExpressionMatchIterator>
 #include <QJsonArray>
 #include <QJsonDocument>
+#include <QRegularExpression>
+#include <QRegularExpressionMatchIterator>
+#include <utility>
 
+#include "notefolder.h"
 
 Bookmark::Bookmark() {
-    url = "";
-    name = "";
+    url = QString();
+    name = QString();
     tags = QStringList();
-    description = "";
+    description = QString();
 }
 
 Bookmark::Bookmark(QString url, QString name, QStringList tagList,
-        QString description) {
+                   QString description) {
     this->url = std::move(url);
     this->name = std::move(name);
     this->tags = std::move(tagList);
     this->description = std::move(description);
 };
 
-
-QJsonObject Bookmark::jsonObject() {
+QJsonObject Bookmark::jsonObject() const {
     QJsonObject bookmarkObject;
-    bookmarkObject.insert("name", QJsonValue::fromVariant(name));
-    bookmarkObject.insert("url", QJsonValue::fromVariant(url));
-    bookmarkObject.insert("tags", QJsonValue::fromVariant(tags));
-    bookmarkObject.insert("description", QJsonValue::fromVariant(description));
+    bookmarkObject.insert(QStringLiteral("name"),
+                          QJsonValue::fromVariant(name));
+    bookmarkObject.insert(QStringLiteral("url"), QJsonValue::fromVariant(url));
+    bookmarkObject.insert(QStringLiteral("tags"),
+                          QJsonValue::fromVariant(tags));
+    bookmarkObject.insert(QStringLiteral("description"),
+                          QJsonValue::fromVariant(description));
     return bookmarkObject;
 };
 
 QDebug operator<<(QDebug dbg, const Bookmark &bookmark) {
-    dbg.nospace() << "Bookmark: <name>" << bookmark.name <<
-                  " <url>" << bookmark.url << " <tags>" << bookmark.tags <<
-                  " <description>" << bookmark.description;
+    dbg.nospace() << "Bookmark: <name>" << bookmark.name << " <url>"
+                  << bookmark.url << " <tags>" << bookmark.tags
+                  << " <description>" << bookmark.description;
     return dbg.space();
 }
 
@@ -54,13 +57,17 @@ bool Bookmark::operator==(const Bookmark &bookmark) const {
  * @param text
  * @return
  */
-QList<Bookmark> Bookmark::parseBookmarks(QString text, bool withBasicUrls) {
+QVector<Bookmark> Bookmark::parseBookmarks(const QString &text,
+                                           bool withBasicUrls) {
     QRegularExpressionMatchIterator i;
-    QList<Bookmark> bookmarks;
+    QVector<Bookmark> bookmarks;
 
-    // parse bookmark links like `- [name](http://link) #tag1 #tag2 the description text`
-    // with optional tags and description
-    i = QRegularExpression(R"([-*] \[(.+?)\]\(([\w-]+://.+?)\)(.*)$)", QRegularExpression::MultilineOption).globalMatch(text);
+    // parse bookmark links like `- [name](http://link) #tag1 #tag2 the
+    // description text` with optional tags and description
+    i = QRegularExpression(
+            QStringLiteral(R"([-*] \[(.+?)\]\(([\w-]+://.+?)\)(.*)$)"),
+            QRegularExpression::MultilineOption)
+            .globalMatch(text);
 
     while (i.hasNext()) {
         QRegularExpressionMatch match = i.next();
@@ -71,10 +78,9 @@ QList<Bookmark> Bookmark::parseBookmarks(QString text, bool withBasicUrls) {
         QString description;
 
         if (!additionalText.isEmpty()) {
-
             QRegularExpressionMatchIterator addIterator =
-                    QRegularExpression(R"(#([^\s#]+))").globalMatch(
-                            additionalText);
+                QRegularExpression(QStringLiteral(R"(#([^\s#]+))"))
+                    .globalMatch(additionalText);
             while (addIterator.hasNext()) {
                 QRegularExpressionMatch addMatch = addIterator.next();
                 QString tag = addMatch.captured(1).trimmed();
@@ -82,15 +88,15 @@ QList<Bookmark> Bookmark::parseBookmarks(QString text, bool withBasicUrls) {
                 if (!tags.contains(tag)) {
                     tags << tag;
                     additionalText.remove(QRegularExpression(
-                            "#" + QRegularExpression::escape(tag) + "\\b"));
+                        "#" + QRegularExpression::escape(tag) + "\\b"));
                 }
             }
 
             description = additionalText.trimmed();
         }
 
-        if (withBasicUrls && !tags.contains("current")) {
-            tags << "current";
+        if (withBasicUrls && !tags.contains(QStringLiteral("current"))) {
+            tags << QStringLiteral("current");
         }
 
         auto bookmark = Bookmark(url, name, tags, description);
@@ -99,25 +105,28 @@ QList<Bookmark> Bookmark::parseBookmarks(QString text, bool withBasicUrls) {
 
     if (withBasicUrls) {
         // parse named links like [name](http://my.site.com)
-        i = QRegularExpression(R"(\[(.+?)\]\(([\w-]+://.+?)\))").globalMatch(text);
+        i = QRegularExpression(QStringLiteral(R"(\[(.+?)\]\(([\w-]+://.+?)\))"))
+                .globalMatch(text);
 
         while (i.hasNext()) {
             QRegularExpressionMatch match = i.next();
             QString name = match.captured(1);
             QString url = match.captured(2);
 
-            auto bookmark = Bookmark(url, name, QStringList() << "current");
+            auto bookmark =
+                Bookmark(url, name, QStringList() << QStringLiteral("current"));
             bookmark.mergeInList(bookmarks);
         }
 
         // parse links like <http://my.site.com>
-        i = QRegularExpression(R"(<([\w-]+://.+?)>)").globalMatch(text);
+        i = QRegularExpression(QStringLiteral(R"(<([\w-]+://.+?)>)"))
+                .globalMatch(text);
 
         while (i.hasNext()) {
             QRegularExpressionMatch match = i.next();
             QString url = match.captured(1);
 
-            auto bookmark = Bookmark(url, "", QStringList() << "current");
+            auto bookmark = Bookmark(url, QString(), QStringList{"current"});
             bookmark.mergeInList(bookmarks);
         }
     }
@@ -130,20 +139,30 @@ QList<Bookmark> Bookmark::parseBookmarks(QString text, bool withBasicUrls) {
  *
  * @return
  */
-QString Bookmark::bookmarksWebServiceJsonText(QList<Bookmark> bookmarks) {
+QString Bookmark::bookmarksWebServiceJsonText(
+    const QVector<Bookmark> &bookmarks) {
     QJsonArray bookmarkObjectList;
+    QJsonArray noteFolderObjectList;
 
-    Q_FOREACH(Bookmark bookmark, bookmarks) {
-            bookmarkObjectList.push_back(bookmark.jsonObject());
-        }
+    for (const Bookmark &bookmark : bookmarks) {
+        bookmarkObjectList.push_back(bookmark.jsonObject());
+    }
+
+    const auto noteFolders = NoteFolder::fetchAll();
+    for (const NoteFolder &noteFolder : noteFolders) {
+        noteFolderObjectList.push_back(noteFolder.jsonObject());
+    }
 
     QJsonObject bookmarkResultObject;
-    bookmarkResultObject.insert("type", QJsonValue::fromVariant("bookmarks"));
-    bookmarkResultObject.insert("data", bookmarkObjectList);
-    bookmarkResultObject.insert("noteFolderName",
-            NoteFolder::currentNoteFolder().getName());
-    bookmarkResultObject.insert("noteFolders",
-            NoteFolder::noteFoldersWebServiceJsonText());
+    bookmarkResultObject.insert(QStringLiteral("type"),
+                                QJsonValue::fromVariant("bookmarks"));
+    bookmarkResultObject.insert(QStringLiteral("data"), bookmarkObjectList);
+    bookmarkResultObject.insert(QStringLiteral("noteFolderName"),
+                                NoteFolder::currentNoteFolder().getName());
+    bookmarkResultObject.insert(QStringLiteral("noteFolders"),
+                                noteFolderObjectList);
+    bookmarkResultObject.insert(QStringLiteral("noteFolderId"),
+                                NoteFolder::currentNoteFolderId());
 
     QJsonDocument doc(bookmarkResultObject);
 
@@ -155,16 +174,15 @@ QString Bookmark::bookmarksWebServiceJsonText(QList<Bookmark> bookmarks) {
  *
  * @return
  */
-QString Bookmark::parsedBookmarksWebServiceJsonText(
-        QString text, bool withBasicUrls) {
-    return bookmarksWebServiceJsonText(parseBookmarks(
-            std::move(text), withBasicUrls));
+QString Bookmark::parsedBookmarksWebServiceJsonText(const QString &text,
+                                                    bool withBasicUrls) {
+    return bookmarksWebServiceJsonText(parseBookmarks(text, withBasicUrls));
 }
 
 /**
  * Merges the current bookmark into a list of bookmarks
  */
-void Bookmark::mergeInList(QList<Bookmark> &bookmarks) {
+void Bookmark::mergeInList(QVector<Bookmark> &bookmarks) {
     int i = bookmarks.indexOf(*this);
 
     if (i == -1) {
@@ -181,12 +199,12 @@ void Bookmark::mergeInList(QList<Bookmark> &bookmarks) {
 /**
  * Merges a bookmark into a list of bookmarks
  */
-void Bookmark::mergeInList(QList<Bookmark> &bookmarks, Bookmark &bookmark) {
+void Bookmark::mergeInList(QVector<Bookmark> &bookmarks, Bookmark &bookmark) {
     bookmark.mergeInList(bookmarks);
 }
 
 /**
- * Merges the current bookmark with an other
+ * Merges the current bookmark with another
  */
 void Bookmark::merge(Bookmark &bookmark) {
     tags.append(bookmark.tags);
@@ -199,7 +217,7 @@ void Bookmark::merge(Bookmark &bookmark) {
 
     if (!description.contains(bookmark.description)) {
         if (!description.isEmpty()) {
-            description += ", ";
+            description += QLatin1String(", ");
         }
 
         description += bookmark.description;
@@ -209,9 +227,9 @@ void Bookmark::merge(Bookmark &bookmark) {
 /**
  * Merges a list of bookmarks into another
  */
-void Bookmark::mergeListInList(QList<Bookmark> &sourceBookmarks,
-                               QList<Bookmark> &destinationBookmarks) {
-    Q_FOREACH(Bookmark bookmark, sourceBookmarks) {
-            bookmark.mergeInList(destinationBookmarks);
-        }
+void Bookmark::mergeListInList(const QVector<Bookmark> &sourceBookmarks,
+                               QVector<Bookmark> &destinationBookmarks) {
+    for (Bookmark bookmark : sourceBookmarks) {
+        bookmark.mergeInList(destinationBookmarks);
+    }
 }
