@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -8,8 +8,8 @@
  * copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
  *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -31,17 +31,19 @@
  */
 
 #include "piwiktracker.h"
-#include <QUrlQuery>
+
 #include <QSettings>
+#include <QUrlQuery>
 #include <QUuid>
+#include <utility>
 
 #if defined(PIWIK_TRACKER_QTQUICK)
 #include <QGuiApplication>
 #include <QScreen>
 #else
 #ifdef QT_GUI_LIB
-#include <QApplication>
-#include <QDesktopWidget>
+#include <QGuiApplication>
+#include <QScreen>
 #endif
 #endif
 
@@ -49,20 +51,15 @@
 #define PIWIK_TRACKER_DEBUG 0
 #endif
 
-PiwikTracker::PiwikTracker(QCoreApplication * parent,
-                           QUrl trackerUrl,
-                           int siteId,
-                           QString clientId) :
-        QObject(parent),
-        _networkAccessManager(this),
-        _trackerUrl(trackerUrl),
-        _siteId(siteId),
-        _clientId(clientId) {
-    connect(
-            &_networkAccessManager,
-            SIGNAL(finished(QNetworkReply *)),
-            this,
-            SLOT(replyFinished(QNetworkReply *)));
+PiwikTracker::PiwikTracker(QCoreApplication* parent, QUrl trackerUrl,
+                           int siteId, QString clientId)
+    : QObject(parent),
+      _networkAccessManager(this),
+      _trackerUrl(std::move(trackerUrl)),
+      _siteId(siteId),
+      _clientId(std::move(clientId)) {
+    connect(&_networkAccessManager, SIGNAL(finished(QNetworkReply*)), this,
+            SLOT(replyFinished(QNetworkReply*)));
 
     if (parent) {
         _appName = parent->applicationName();
@@ -74,13 +71,11 @@ PiwikTracker::PiwikTracker(QCoreApplication * parent,
         // create a client id if none was in the settings
         if (!settings.contains("PiwikClientId")) {
             QByteArray ba;
-            ba.append(QUuid::createUuid().toString());
+            ba.append(QUuid::createUuid().toByteArray());
 
             // generate a random md5 hash
             QString md5Hash = QString(
-                    QCryptographicHash::hash(
-                            ba,
-                            QCryptographicHash::Md5).toHex());
+                QCryptographicHash::hash(ba, QCryptographicHash::Md5).toHex());
 
             // the client id has to be a 16 character hex code
             _clientId = md5Hash.left(16);
@@ -95,19 +90,20 @@ PiwikTracker::PiwikTracker(QCoreApplication * parent,
 
     // get the screen resolution for gui apps
 #if defined(PIWIK_TRACKER_QTQUICK)
-    QScreen* screen = qApp->primaryScreen();
-    _screenResolution = QString::number(screen->geometry().width())
-        + "x" + QString::number(screen->geometry().height());
+    QScreen *primaryScreen = qApp->primaryScreen();
 #else
 #ifdef QT_GUI_LIB
-    _screenResolution =
-            QString::number(
-                    QApplication::desktop()->screenGeometry().width()) + "x"
-                    + QString::number(
-                    QApplication::desktop()->screenGeometry().height());
+    QScreen *primaryScreen = QGuiApplication::primaryScreen();
 #endif
 #endif
 
+#if defined(PIWIK_TRACKER_QTQUICK) || defined(QT_GUI_LIB)
+    if (primaryScreen != nullptr) {
+        _screenResolution = QString::number(primaryScreen->geometry().width()) +
+                "x" + QString::number(primaryScreen->geometry().height());
+    }
+#endif
+
     // try to get the operating system
     QString operatingSystem = "Other";
 
@@ -124,13 +120,13 @@ PiwikTracker::PiwikTracker(QCoreApplication * parent,
 #endif
 
     // for QT >= 5.4 we can use QSysInfo
-    // Piwik doesn't recognize that on Mac OS X very well
+    // Piwik doesn't recognize that on macOS very well
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 4, 0))
 #ifdef Q_OS_MAC
     operatingSystem = "Macintosh " + QSysInfo::prettyProductName();
 #else
-    operatingSystem = QSysInfo::prettyProductName() +", " +
-            QSysInfo::currentCpuArchitecture();
+    operatingSystem = QSysInfo::prettyProductName() + ", " +
+                      QSysInfo::currentCpuArchitecture();
 #endif
 #endif
 
@@ -138,8 +134,9 @@ PiwikTracker::PiwikTracker(QCoreApplication * parent,
     QString locale = QLocale::system().name().toLower().replace("_", "-");
 
     // set the user agent
-    _userAgent = "Mozilla/5.0 (" + operatingSystem + "; " + locale + ") "
-                      "PiwikTracker/0.1 (Qt/" QT_VERSION_STR " )";
+    _userAgent = "Mozilla/5.0 (" + operatingSystem + "; " + locale +
+                 ") "
+                 "PiwikTracker/0.1 (Qt/" QT_VERSION_STR " )";
 
     // set the user language
     _userLanguage = locale;
@@ -148,7 +145,7 @@ PiwikTracker::PiwikTracker(QCoreApplication * parent,
 /**
  * Prepares the common query items for the tracking request
  */
-QUrlQuery PiwikTracker::prepareUrlQuery(QString path) {
+QUrlQuery PiwikTracker::prepareUrlQuery(const QString& path) {
     QUrlQuery q;
     q.addQueryItem("idsite", QString::number(_siteId));
     q.addQueryItem("_id", _clientId);
@@ -183,23 +180,24 @@ QUrlQuery PiwikTracker::prepareUrlQuery(QString path) {
     return q;
 }
 
-QString PiwikTracker::getVisitVariables()
-{
+QString PiwikTracker::getVisitVariables() {
     QString varString;
     /**
-      * See spec at https://github.com/piwik/piwik/issues/2165
-      * Need to pass in format {"1":["key1","value1"],"2":["key2","value2"]}
-      */
-    if( _visitVariables.count() > 0 ) {
+     * See spec at https://github.com/piwik/piwik/issues/2165
+     * Need to pass in format {"1":["key1","value1"],"2":["key2","value2"]}
+     */
+    if (_visitVariables.count() > 0) {
         QHash<QString, QString>::iterator i;
         varString.append("{");
-        int num=0;
+        int num = 0;
         for (i = _visitVariables.begin(); i != _visitVariables.end(); ++i) {
-            if( num != 0 )
-            {
+            if (num != 0) {
                 varString.append(",");
             }
-            QString thisvar=QString("\"%1\":[\"%2\",\"%3\"]").arg(num+1).arg(i.key()).arg(i.value());
+            QString thisvar = QString(R"("%1":["%2","%3"])")
+                                  .arg(num + 1)
+                                  .arg(i.key())
+                                  .arg(i.value());
             varString.append(thisvar);
             num++;
         }
@@ -208,34 +206,33 @@ QString PiwikTracker::getVisitVariables()
     return varString;
 }
 
-
 /**
  * Sends a visit request with visit variables
  */
-void PiwikTracker::sendVisit(QString path, QString actionName) {
+void PiwikTracker::sendVisit(const QString& path, const QString& actionName) {
     QUrl url(_trackerUrl.toString() + "/piwik.php");
     QUrlQuery q = prepareUrlQuery(path);
-    QString visitVars=getVisitVariables();
+    QString visitVars = getVisitVariables();
 
-    if( visitVars.size() != 0 )
-    {
-        q.addQueryItem("_cvar",visitVars);
+    if (visitVars.size() != 0) {
+        q.addQueryItem("_cvar", visitVars);
     }
     if (!actionName.isEmpty()) {
         q.addQueryItem("action_name", actionName);
     }
 
-
     url.setQuery(q);
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
     // try to ensure the network is accessible
     _networkAccessManager.setNetworkAccessible(
-            QNetworkAccessManager::Accessible);
+        QNetworkAccessManager::Accessible);
+#endif
 
-    QNetworkReply *reply = _networkAccessManager.get(QNetworkRequest(url));
+    QNetworkReply* reply = _networkAccessManager.get(QNetworkRequest(url));
 
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
-            this, SLOT(replyError(QNetworkReply::NetworkError)));
+    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this,
+            SLOT(replyError(QNetworkReply::NetworkError)));
 
     // ignoring SSL errors
     connect(reply, SIGNAL(sslErrors(QList<QSslError>)), reply,
@@ -255,14 +252,16 @@ void PiwikTracker::sendPing() {
     q.addQueryItem("ping", "1");
     url.setQuery(q);
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
     // try to ensure the network is accessible
     _networkAccessManager.setNetworkAccessible(
-            QNetworkAccessManager::Accessible);
+        QNetworkAccessManager::Accessible);
+#endif
 
-    QNetworkReply *reply = _networkAccessManager.get(QNetworkRequest(url));
+    QNetworkReply* reply = _networkAccessManager.get(QNetworkRequest(url));
 
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
-            this, SLOT(replyError(QNetworkReply::NetworkError)));
+    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this,
+            SLOT(replyError(QNetworkReply::NetworkError)));
 
     // ignoring SSL errors
     connect(reply, SIGNAL(sslErrors(QList<QSslError>)), reply,
@@ -276,12 +275,9 @@ void PiwikTracker::sendPing() {
 /**
  * Sends an event request
  */
-void PiwikTracker::sendEvent(
-        QString path,
-        QString eventCategory,
-        QString eventAction,
-        QString eventName,
-        int eventValue) {
+void PiwikTracker::sendEvent(const QString& path, const QString& eventCategory,
+                             const QString& eventAction,
+                             const QString& eventName, int eventValue) {
     QUrl url(_trackerUrl.toString() + "/piwik.php");
     QUrlQuery q = prepareUrlQuery(path);
 
@@ -301,14 +297,16 @@ void PiwikTracker::sendEvent(
 
     url.setQuery(q);
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
     // try to ensure the network is accessible
     _networkAccessManager.setNetworkAccessible(
-            QNetworkAccessManager::Accessible);
+        QNetworkAccessManager::Accessible);
+#endif
 
-    QNetworkReply *reply = _networkAccessManager.get(QNetworkRequest(url));
+    QNetworkReply* reply = _networkAccessManager.get(QNetworkRequest(url));
 
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
-            this, SLOT(replyError(QNetworkReply::NetworkError)));
+    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this,
+            SLOT(replyError(QNetworkReply::NetworkError)));
 
     // ignoring SSL errors
     connect(reply, SIGNAL(sslErrors(QList<QSslError>)), reply,
@@ -323,7 +321,7 @@ void PiwikTracker::sendEvent(
  * Sets a custom dimension
  */
 void PiwikTracker::setCustomDimension(int id, QString value) {
-    _customDimensions[id] = value;
+    _customDimensions[id] = std::move(value);
 }
 
 /**
@@ -331,11 +329,11 @@ void PiwikTracker::setCustomDimension(int id, QString value) {
  * @param name The name of the custom variable to set (key)
  * @param value The value to set for this custom variable
  */
-void PiwikTracker::setCustomVisitVariables(QString name, QString value) {
-    _visitVariables[name]=value;
+void PiwikTracker::setCustomVisitVariables(const QString& name, QString value) {
+    _visitVariables[name] = std::move(value);
 }
 
-void PiwikTracker::replyFinished(QNetworkReply * reply) {
+void PiwikTracker::replyFinished(QNetworkReply* reply) {
 #if PIWIK_TRACKER_DEBUG
     qDebug() << "Reply from " << reply->url().path();
 #else
