@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -8,8 +8,8 @@
  * copies of the Software, and to permit persons to whom the Software is
  * furnished to do so, subject to the following conditions:
  *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -24,31 +24,25 @@
 
 #include <QCoreApplication>
 #include <QNetworkAccessManager>
-#include <QNetworkRequest>
 #include <QNetworkReply>
+#include <QNetworkRequest>
 #include <QUrl>
 
-
 class PiwikTracker : public QObject {
     Q_OBJECT
 
-public:
-    explicit PiwikTracker(QCoreApplication * parent,
-                          QUrl trackerUrl,
-                          int siteId,
+   public:
+    explicit PiwikTracker(QCoreApplication* parent, QUrl trackerUrl, int siteId,
                           QString clientId = "");
-    void sendVisit(QString path, QString actionName = "");
+    void sendVisit(const QString& path, const QString& actionName = "");
     void sendPing();
-    void sendEvent(
-            QString path,
-            QString eventCategory,
-            QString eventAction,
-            QString eventName = "",
-            int eventValue = 0);
+    void sendEvent(const QString& path, const QString& eventCategory,
+                   const QString& eventAction, const QString& eventName = "",
+                   int eventValue = 0);
     void setCustomDimension(int id, QString value);
-    void setCustomVisitVariables(QString key, QString value);
+    void setCustomVisitVariables(const QString& key, QString value);
 
-private:
+   private:
     mutable QNetworkAccessManager _networkAccessManager;
     QString _appName;
     QUrl _trackerUrl;
@@ -59,10 +53,10 @@ private:
     QString _userLanguage;
     QHash<int, QString> _customDimensions;
     QHash<QString, QString> _visitVariables;
-    QUrlQuery prepareUrlQuery(QString path);
+    QUrlQuery prepareUrlQuery(const QString& path);
     QString getVisitVariables();
-private Q_SLOTS:
+   private Q_SLOTS:
 
-    void replyFinished(QNetworkReply * reply);
+    void replyFinished(QNetworkReply* reply);
     void replyError(QNetworkReply::NetworkError code);
 };
