@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,38 +14,43 @@
 
 #pragma once
 
-#include <QWidget>
 #include <QPlainTextEdit>
+#include <QWidget>
 
 namespace Ui {
 class QPlainTextEditSearchWidget;
 }
 
-class QPlainTextEditSearchWidget : public QWidget
-{
+class QPlainTextEditSearchWidget : public QWidget {
     Q_OBJECT
 
-public:
-    enum SearchMode {
-        PlainTextMode,
-        WholeWordsMode,
-        RegularExpressionMode
-    };
+   public:
+    enum SearchMode { PlainTextMode, WholeWordsMode, RegularExpressionMode };
 
-    explicit QPlainTextEditSearchWidget(QPlainTextEdit *parent = 0);
-    bool doSearch(bool searchDown = true, bool allowRestartAtTop = true);
+    explicit QPlainTextEditSearchWidget(QPlainTextEdit *parent = nullptr);
+    bool doSearch(bool searchDown = true, bool allowRestartAtTop = true,
+                  bool updateUI = true);
     void setDarkMode(bool enabled);
     ~QPlainTextEditSearchWidget();
+    void setSearchText(const QString &searchText);
+    void setSearchMode(SearchMode searchMode);
+    void activate(bool focus);
+    void updateSearchExtraSelections();
 
-private:
+   private:
     Ui::QPlainTextEditSearchWidget *ui;
+    int _searchResultCount;
+    int _currentSearchResult;
+    QList<QTextEdit::ExtraSelection> _searchExtraSelections;
+    QColor selectionColor;
+    void setSearchExtraSelections() const;
 
-protected:
+   protected:
     QPlainTextEdit *_textEdit;
     bool _darkMode;
     bool eventFilter(QObject *obj, QEvent *event);
 
-public slots:
+   public slots:
     void activate();
     void deactivate();
     void doSearchDown();
@@ -54,7 +59,14 @@ public slots:
     void activateReplace();
     bool doReplace(bool forAll = false);
     void doReplaceAll();
+    void reset();
+    void doSearchCount();
 
-protected slots:
+   protected slots:
     void searchLineEditTextChanged(const QString &arg1);
+    void updateSearchCountLabelText();
+    void setSearchSelectionColor(const QColor &color);
+   private slots:
+    void on_modeComboBox_currentIndexChanged(int index);
+    void on_matchCaseSensitiveButton_toggled(bool checked);
 };
