@@ -36,7 +36,7 @@ private:
                                      ElementInfo& elemInfo);
 
     // Try to find end position of first or middle element
-    static int FindMiddleElementPositioin(const QString& str,
+    static int FindMiddleElementPosition(const QString& str,
                                           const int& startPos,
                                           const QString& separator,
                                           const QString& txtDelim);
@@ -89,7 +89,9 @@ bool ReaderPrivate::read(const QString& filePath,
     }
 
     QTextStream stream(&csvFile);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     stream.setCodec(codec);
+#endif
 
     // This list will contain elements of the row if elements of this row
     // are located on several lines
@@ -228,7 +230,7 @@ QStringList ReaderPrivate::splitElements(const QString& line,
                 // 1. Be the first or the middle element. Then it should end
                 // with delimiter and the seprator symbols standing next to each
                 // other.
-                int midElemEndPos = FindMiddleElementPositioin(
+                int midElemEndPos = FindMiddleElementPosition(
                                         line, pos, separator, textDelimiter);
                 if (midElemEndPos > 0)
                 {
@@ -289,7 +291,7 @@ QStringList ReaderPrivate::splitElements(const QString& line,
             // 1. End somewhere in the middle of the line. Then it should end
             // with delimiter and the seprator symbols standing next to each
             // other.
-            int midElemEndPos = FindMiddleElementPositioin(
+            int midElemEndPos = FindMiddleElementPosition(
                                 line, pos, separator, textDelimiter);
             if (midElemEndPos > 0)
             {
@@ -327,7 +329,7 @@ QStringList ReaderPrivate::splitElements(const QString& line,
 // @output:
 // - int - end position of the element or -1 if this element is not first
 // or middle
-int ReaderPrivate::FindMiddleElementPositioin(const QString& str,
+int ReaderPrivate::FindMiddleElementPosition(const QString& str,
                                               const int& startPos,
                                               const QString& separator,
                                               const QString& txtDelim)
@@ -361,8 +363,8 @@ int ReaderPrivate::FindMiddleElementPositioin(const QString& str,
         int numOfDelimiters = 0;
         for (int pos = elemEndPos; startPos <= pos; --pos, ++numOfDelimiters)
         {
-            QStringRef strRef = str.midRef(pos, txtDelim.size());
-            if (QStringRef::compare(strRef, txtDelim) != 0)
+            QString strRef = str.mid(pos, txtDelim.size());
+            if (QString::compare(strRef, txtDelim) != 0)
             {
                 break;
             }
@@ -423,8 +425,8 @@ bool ReaderPrivate::IsElementLast(const QString& str,
     int numOfDelimiters = 0;
     for (int pos = str.size() - 1; startPos <= pos; --pos, ++numOfDelimiters)
     {
-        QStringRef strRef = str.midRef(pos, txtDelim.size());
-        if (QStringRef::compare(strRef, txtDelim) != 0)
+        QString strRef = str.mid(pos, txtDelim.size());
+        if (QString::compare(strRef, txtDelim) != 0)
         {
             break;
         }
