@@ -27,6 +27,10 @@
 #include <QtCore/QSharedMemory>
 #include <QtCore/QUuid>
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+#include <QtCore/QRandomGenerator>
+#endif
+
 #include "singleapplication.h"
 #include "singleapplication_p.h"
 
@@ -93,8 +97,14 @@ SingleApplication::SingleApplication( int &argc, char *argv[], bool allowSeconda
         d->memory->unlock();
 
         // Random sleep here limits the probability of a colision between two racing apps
+#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
         qsrand( QDateTime::currentMSecsSinceEpoch() % std::numeric_limits<uint>::max() );
-        QThread::sleep( 8 + static_cast <unsigned long>( static_cast <float>( qrand() ) / RAND_MAX * 10 ) );
+        const quint32 number = qrand();
+#else
+        const quint32 number = QRandomGenerator::global()->generate();
+#endif
+
+        QThread::sleep( 8 + static_cast <unsigned long>( static_cast <float>( number ) / RAND_MAX * 10 ) );
     }
 
     if( inst->primary == false) {
@@ -206,7 +216,7 @@ qint64 SingleApplication::primaryPid()
     return d->primaryPid();
 }
 
-bool SingleApplication::sendMessage( QByteArray message, int timeout )
+bool SingleApplication::sendMessage( const QByteArray& message, int timeout )
 {
     Q_D(SingleApplication);
 
