@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,51 +14,65 @@
 
 #pragma once
 
-#include <QMainWindow>
-#include <QListWidgetItem>
-#include <QFileSystemWatcher>
-#include <QHash>
-#include <QFileDialog>
-#include <QEvent>
-#include <QSignalMapper>
-#include <QSystemTrayIcon>
-#include <QTextEdit>
-#include <QFile>
-#include <QToolBar>
-#include <QTreeWidgetItem>
-#include <QShortcut>
 #include <entities/note.h>
-#include <entities/notefolder.h>
-#include <entities/tag.h>
-#include <services/scriptingservice.h>
-#include <QScrollArea>
-#include <QDockWidget>
-#include <QComboBox>
-#include <dialogs/actiondialog.h>
-#include <dialogs/tododialog.h>
-#include <dialogs/settingsdialog.h>
-#include <QPrinter>
+#include <libraries/qhotkey/QHotkey/qhotkey.h>
+#include <services/webappclientservice.h>
 #include <widgets/logwidget.h>
-#include <dialogs/orphanedimagesdialog.h>
-#include <dialogs/orphanedattachmentsdialog.h>
-#include <dialogs/issueassistantdialog.h>
+
+#include <QFileSystemWatcher>
+#include <QMainWindow>
+#include <QSystemTrayIcon>
+
 #include "entities/notehistory.h"
-#include "dialogs/notediffdialog.h"
-#include "services/updateservice.h"
-#include "widgets/qownnotesmarkdowntextedit.h"
-#include <libraries/fakevim/fakevim/fakevimhandler.h>
-#include "services/websocketserverservice.h"
 
 #define SORT_ALPHABETICAL 0
 #define SORT_BY_LAST_CHANGE 1
-#define ORDER_ASCENDING 0 // Qt::AscendingOrder // = 0
-#define ORDER_DESCENDING 1 // Qt::DescendingOrder // = 1
+#define ORDER_ASCENDING 0     // Qt::AscendingOrder // = 0
+#define ORDER_DESCENDING 1    // Qt::DescendingOrder // = 1
 
 namespace Ui {
 class MainWindow;
 }
 
+class QMimeData;
+class QActionGroup;
+class QListWidgetItem;
+class QFileSystemWatcher;
+class QFileDialog;
+class QEvent;
+class QSystemTrayIcon;
+class QPlainTextEdit;
+class QTextEdit;
+class QTextDocument;
+class QLabel;
+class QPushButton;
+class QFile;
+class QToolBar;
+class QTreeWidget;
+class QTreeWidgetItem;
+class QShortcut;
+class Note;
+class NoteFolder;
+class Tag;
+class ScriptingService;
+class QScrollArea;
+class QDockWidget;
+class QComboBox;
+class ActionDialog;
+class TodoDialog;
+class QPrinter;
+class LogWidget;
+class StoredImagesDialog;
+class StoredAttachmentsDialog;
+class IssueAssistantDialog;
+class NoteHistory;
+class NoteDiffDialog;
+class UpdateService;
+class FakeVimHandler;
+class WebSocketServerService;
 class QOwnNotesMarkdownTextEdit;
+class CommandBar;
+struct TagHeader;
 
 // forward declaration because of "xxx does not name a type"
 class TodoDialog;
@@ -66,14 +80,14 @@ class SettingsDialog;
 
 class MainWindow : public QMainWindow {
     Q_OBJECT
-    Q_PROPERTY(Note currentNote WRITE setCurrentNote MEMBER currentNote
-                       NOTIFY currentNoteChanged)
+    Q_PROPERTY(Note currentNote WRITE setCurrentNote MEMBER currentNote NOTIFY
+                   currentNoteChanged)
 
-Q_SIGNALS:
+   Q_SIGNALS:
     void currentNoteChanged(Note &note);
     void log(LogWidget::LogType logType, QString text);
 
-public:
+   public:
     enum CreateNewNoteOption {
         None = 0x0000,
 
@@ -87,25 +101,32 @@ public:
         DisableLoadNoteDirectoryList = 0x0004,
     };
 
+    enum NoteTreeWidgetItemType {
+        NoteType = 1,
+        FolderType = 2,
+    };
+
     Q_DECLARE_FLAGS(CreateNewNoteOptions, CreateNewNoteOption)
 
-    explicit MainWindow(QWidget *parent = 0);
+    explicit MainWindow(QWidget *parent = nullptr);
 
     ~MainWindow();
 
+    void triggerStartupMenuAction();
+
     void setCurrentNoteText(QString text);
 
     Note getCurrentNote();
 
     void createNewNote(
-            QString name, QString text,
-            CreateNewNoteOptions options = CreateNewNoteOption::None);
+        QString name, QString text,
+        CreateNewNoteOptions options = CreateNewNoteOption::None);
 
     void openSettingsDialog(int page = 0, bool openScriptRepository = false);
 
-    void restoreTrashedNoteOnServer(QString fileName, int timestamp);
+    void restoreTrashedNoteOnServer(const QString &fileName, int timestamp);
 
-    void showUpdateAvailableButton(QString version);
+    void showUpdateAvailableButton(const QString &version);
 
     void hideUpdateAvailableButton();
 
@@ -113,7 +134,7 @@ public:
 
     void enableShowTrashButton();
 
-    void showStatusBarMessage(const QString & message, int timeout = 0);
+    void showStatusBarMessage(const QString &message, const int timeout = 4000);
 
     void handleInsertingFromMimeData(const QMimeData *mimeData);
 
@@ -123,25 +144,26 @@ public:
 
     QList<QMenu *> menuList();
 
-    QAction *findAction(QString objectName);
+    QAction *findAction(const QString &objectName);
 
-    void addCustomAction(QString identifier, QString menuText,
-                         QString buttonText, QString icon,
+    void addCustomAction(const QString &identifier, const QString &menuText,
+                         const QString &buttonText, const QString &icon,
                          bool useInNoteEditContextMenu = false,
                          bool hideButtonInToolbar = false,
                          bool useInNoteListContextMenu = false);
 
-    void addScriptingLabel(QString identifier, QString text = "");
+    void addScriptingLabel(const QString &identifier,
+                           const QString &text = QString());
 
-    void setScriptingLabelText(QString identifier, QString text);
+    void setScriptingLabelText(const QString &identifier, const QString &text);
 
     void preReloadScriptingEngine();
 
-    void writeToNoteTextEdit(QString text);
+    void writeToNoteTextEdit(const QString &text);
 
     QString selectedNoteTextEditText();
 
-    void linkTagNameToCurrentNote(QString tagName,
+    void linkTagNameToCurrentNote(const QString &tagName,
                                   bool linkToSelectedNotes = false);
 
     Q_INVOKABLE void reloadTagTree();
@@ -149,15 +171,15 @@ public:
     Q_INVOKABLE void reloadNoteSubFolderTree();
 
     Q_INVOKABLE void buildNotesIndexAndLoadNoteDirectoryList(
-            bool forceBuild = false, bool forceLoad = false);
+        bool forceBuild = false, bool forceLoad = false, bool reloadTabs = true);
 
-    QList<Note> selectedNotes();
+    QVector<Note> selectedNotes();
 
     bool jumpToNoteSubFolder(int noteSubFolderId);
 
     QString noteTextEditCurrentWord(bool withPreviousCharacters = false);
 
-    Q_INVOKABLE void focusNoteTextEdit();
+    Q_INVOKABLE bool createNewNoteSubFolder(QString folderName = QString());
 
     QString getLogText();
 
@@ -165,23 +187,48 @@ public:
 
     void openIssueAssistantDialog();
 
-    void insertHtml(QString html);
+    Q_INVOKABLE void insertHtmlAsMarkdownIntoCurrentNote(QString html);
 
-protected:
-    void closeEvent(QCloseEvent *event);
+    void resetBrokenTagNotesLinkFlag();
 
-    bool eventFilter(QObject *obj, QEvent *event);
+    Q_INVOKABLE QString getWorkspaceUuid(const QString &workspaceName);
 
-    void resizeEvent(QResizeEvent* event);
+    Q_INVOKABLE void reloadCurrentNoteByNoteId(bool updateNoteText = false);
 
-public slots:
-    void setCurrentNoteFromNoteId(int noteId);
+    Q_INVOKABLE QStringList getWorkspaceUuidList();
+
+    Q_INVOKABLE void setCurrentWorkspace(const QString &uuid);
+
+    Q_INVOKABLE bool insertDataUrlAsFileIntoCurrentNote(const QString &dataUrl);
+
+   protected:
+    void changeEvent(QEvent *event) override;
+
+    void closeEvent(QCloseEvent *event) override;
+
+    bool eventFilter(QObject *obj, QEvent *event) override;
+
+    void resizeEvent(QResizeEvent *event) override;
+
+   public slots:
+    void setCurrentNoteFromNoteId(const int noteId);
 
     void regenerateNotePreview();
 
     void storeUpdatedNotesToDisk();
 
-private slots:
+    void changeNoteFolder(const int noteFolderId,
+                          const bool forceChange = false);
+
+    void allowNoteEditing();
+
+    void disallowNoteEditing();
+
+    void openCurrentNoteInTab();
+
+    Q_INVOKABLE void focusNoteTextEdit();
+
+   private slots:
 
     void on_noteTextEdit_textChanged();
 
@@ -207,8 +254,6 @@ private slots:
 
     void on_action_New_note_triggered();
 
-    void changeNoteFolder(int noteFolderId, bool forceChange = false);
-
     void on_noteTextView_anchorClicked(const QUrl &arg1);
 
     void on_actionCheck_for_updates_triggered();
@@ -231,11 +276,11 @@ private slots:
 
     void jumpToWelcomeNote();
 
-    void on_noteTextEdit_customContextMenuRequested(const QPoint &pos);
+    void on_noteTextEdit_customContextMenuRequested(const QPoint pos);
 
     void pasteMediaIntoNote();
 
-    void on_actionInsert_Link_to_note_triggered();
+    void on_actionInsert_text_link_triggered();
 
     void on_action_DuplicateText_triggered();
 
@@ -249,7 +294,7 @@ private slots:
 
     void on_actionInsert_current_time_triggered();
 
-    void on_actionOpen_List_triggered();
+    void on_actionShow_Todo_List_triggered();
 
     void frequentPeriodicChecker();
 
@@ -281,7 +326,7 @@ private slots:
 
     void on_action_Export_note_as_markdown_triggered();
 
-    void showEvent(QShowEvent *event);
+    void showEvent(QShowEvent *event) override;
 
     void on_actionGet_invloved_triggered();
 
@@ -307,9 +352,9 @@ private slots:
 
     void dfmEditorWidthActionTriggered(QAction *action);
 
-    void dragEnterEvent(QDragEnterEvent *e);
+    void dragEnterEvent(QDragEnterEvent *e) override;
 
-    void dropEvent(QDropEvent *e);
+    void dropEvent(QDropEvent *e) override;
 
     void on_actionPaste_image_triggered();
 
@@ -317,6 +362,8 @@ private slots:
 
     void on_actionFormat_text_bold_triggered();
 
+    void on_actionFormat_text_underline_triggered();
+
     void on_actionFormat_text_italic_triggered();
 
     void on_action_Increase_note_text_size_triggered();
@@ -353,9 +400,12 @@ private slots:
 
     void on_tagTreeWidget_itemChanged(QTreeWidgetItem *item, int column);
 
-    void on_tagTreeWidget_currentItemChanged(QTreeWidgetItem *current, QTreeWidgetItem *previous);
+    void on_tagTreeWidget_currentItemChanged(QTreeWidgetItem *current,
+                                             QTreeWidgetItem *previous);
 
-    void on_tagTreeWidget_customContextMenuRequested(const QPoint &pos);
+    void on_tagTreeWidget_itemSelectionChanged();
+
+    void on_tagTreeWidget_customContextMenuRequested(const QPoint pos);
 
     void moveSelectedTagsToTagId(int tagId);
 
@@ -387,7 +437,7 @@ private slots:
 
     void reloadTodoLists();
 
-    void openTodoDialog(QString taskUid = "");
+    void openTodoDialog(const QString &taskUid = QString());
 
     void showWindow();
 
@@ -401,13 +451,19 @@ private slots:
 
     void on_actionShow_status_bar_triggered(bool checked);
 
-    void on_noteTreeWidget_currentItemChanged(QTreeWidgetItem *current, QTreeWidgetItem *previous);
+    void on_noteTreeWidget_currentItemChanged(QTreeWidgetItem *current,
+                                              QTreeWidgetItem *previous);
 
-    void on_noteTreeWidget_customContextMenuRequested(const QPoint &pos);
+    void on_noteTreeWidget_customContextMenuRequested(const QPoint pos);
 
     void on_noteTreeWidget_itemChanged(QTreeWidgetItem *item, int column);
 
-    void on_noteSubFolderTreeWidget_currentItemChanged(QTreeWidgetItem *current, QTreeWidgetItem *previous);
+    void on_noteSubFolderTreeWidget_currentItemChanged(
+        QTreeWidgetItem *current, QTreeWidgetItem *previous);
+
+    void on_noteSubFolderTreeWidget_itemSelectionChanged();
+
+    void clearTagFilteringColumn();
 
     void on_noteSubFolderLineEdit_textChanged(const QString &arg1);
 
@@ -415,11 +471,13 @@ private slots:
 
     void on_noteSubFolderTreeWidget_itemCollapsed(QTreeWidgetItem *item);
 
-    void on_noteSubFolderTreeWidget_customContextMenuRequested(const QPoint &pos);
+    void on_noteSubFolderTreeWidget_customContextMenuRequested(
+        const QPoint pos);
 
     void on_noteSubFolderLineEdit_returnPressed();
 
-    void on_noteSubFolderTreeWidget_itemChanged(QTreeWidgetItem *item, int column);
+    void on_noteSubFolderTreeWidget_itemChanged(QTreeWidgetItem *item,
+                                                int column);
 
     void on_actionShare_note_triggered();
 
@@ -437,7 +495,7 @@ private slots:
 
     void on_actionSplit_note_at_cursor_position_triggered();
 
-    void onCustomActionInvoked(QString identifier);
+    void onCustomActionInvoked(const QString &identifier);
 
     void on_actionDonate_triggered();
 
@@ -445,7 +503,7 @@ private slots:
 
     void on_actionImport_notes_from_Evernote_triggered();
 
-    void on_actionDelete_orphaned_images_triggered();
+    void on_actionManage_stored_images_triggered();
 
     void on_actionGitter_triggered();
 
@@ -459,19 +517,17 @@ private slots:
 
     void on_actionRename_current_workspace_triggered();
 
-    void setCurrentWorkspace(QString uuid);
-
     void on_actionSwitch_to_previous_workspace_triggered();
 
     void on_actionShow_all_panels_triggered();
 
-    void restoreCurrentWorkspace();
+    Q_SLOT void restoreCurrentWorkspace();
 
-    void togglePanelVisibility(QString objectName);
+    void togglePanelVisibility(const QString &objectName);
 
     void updatePanelMenu();
 
-    void toggleToolbarVisibility(QString objectName);
+    void toggleToolbarVisibility(const QString &objectName);
 
     void updateToolbarMenu();
 
@@ -503,8 +559,6 @@ private slots:
 
     bool restoreActiveNoteHistoryItem();
 
-    void on_noteTextView_customContextMenuRequested(const QPoint &pos);
-
     void on_actionShow_note_git_versions_triggered();
 
     void on_tagTreeWidget_itemCollapsed(QTreeWidgetItem *item);
@@ -529,19 +583,17 @@ private slots:
 
     void on_actionShow_local_trash_triggered();
 
-    void on_encryptedNoteTextEdit_customContextMenuRequested(const QPoint &pos);
+    void on_encryptedNoteTextEdit_customContextMenuRequested(const QPoint pos);
 
     void on_actionJump_to_note_text_edit_triggered();
 
-    void allowNoteEditing();
-
     void on_tagTreeWidget_itemDoubleClicked(QTreeWidgetItem *item, int column);
 
     void on_noteTreeWidget_itemDoubleClicked(QTreeWidgetItem *item, int column);
 
     void on_noteTreeWidget_itemSelectionChanged();
 
-    void on_actionManage_orphaned_attachments_triggered();
+    void on_actionManage_stored_attachments_triggered();
 
     void on_noteOperationsButton_clicked();
 
@@ -557,6 +609,74 @@ private slots:
 
     void initWebSocketServerService();
 
+    void initWebAppClientService();
+
+    void on_actionJump_to_note_list_panel_triggered();
+
+    void on_actionJump_to_tags_panel_triggered();
+
+    void on_actionJump_to_note_subfolder_panel_triggered();
+
+    void on_actionActivate_context_menu_triggered();
+
+    void on_actionImport_bookmarks_from_server_triggered();
+
+    void on_actionElementMatrix_triggered();
+
+    void on_actionToggle_fullscreen_triggered();
+
+    void disableFullScreenMode();
+
+    void moveSelectedNotesToFolder(const QString &destinationFolder);
+
+    void copySelectedNotesToFolder(const QString &destinationFolder,
+                                   const QString &noteFolderPath = QString());
+
+    void on_actionTypewriter_mode_toggled(bool arg1);
+
+    // Spellchecker actions
+    void on_actionCheck_spelling_toggled(bool checked);
+
+    void onLanguageChanged(QAction *action);
+
+    void onBackendChanged(QAction *action);
+
+    void on_actionManage_dictionaries_triggered();
+
+    void on_noteTextEdit_modificationChanged(bool arg1);
+
+    void on_encryptedNoteTextEdit_modificationChanged(bool arg1);
+
+    void on_actionEditorWidthCustom_triggered();
+
+    void on_actionShow_Hide_application_triggered();
+
+    void on_noteEditTabWidget_currentChanged(int index);
+
+    void on_noteEditTabWidget_tabCloseRequested(int index);
+
+    void on_actionPrevious_note_tab_triggered();
+
+    void on_actionNext_note_tab_triggered();
+
+    void on_actionClose_current_note_tab_triggered();
+
+    void on_actionNew_note_in_new_tab_triggered();
+
+    void on_noteEditTabWidget_tabBarDoubleClicked(int index);
+
+    void on_actionToggle_note_stickiness_of_current_tab_triggered();
+
+    void on_noteEditTabWidget_tabBarClicked(int index);
+
+    void showNoteEditTabWidgetContextMenu(const QPoint &point);
+
+    void on_actionJump_to_navigation_panel_triggered();
+
+    void on_actionInsert_note_link_triggered();
+
+    void on_actionImport_notes_from_Joplin_triggered();
+
 private:
     Ui::MainWindow *ui;
     QString notesPath;
@@ -564,21 +684,15 @@ private:
     Note currentNote;
     QString _currentNoteTextHash;
     NoteDiffDialog *noteDiffDialog;
-    QSignalMapper *recentNoteFolderSignalMapper;
-    QSignalMapper *storeNoteBookmarkSignalMapper;
-    QSignalMapper *gotoNoteBookmarkSignalMapper;
-    QSignalMapper *_customActionSignalMapper;
-    QSignalMapper *_workspaceSignalMapper;
-    QSignalMapper *_panelSignalMapper;
-    QSignalMapper *_toolbarSignalMapper;
     UpdateService *updateService;
     bool showSystemTray;
     QSystemTrayIcon *trayIcon;
     QDateTime currentNoteLastEdited;
+    QDateTime _lastHeartbeat;
     bool notifyAllExternalModifications;
     int noteSaveIntervalTime;
     QTimer *noteSaveTimer;
-    QTimer *todoReminderTimer;
+    QTimer *_frequentPeriodicTimer;
     QTimer *_noteViewUpdateTimer;
     QTimer *_gitCommitTimer;
     QTimer *_todoListTimer;
@@ -589,6 +703,7 @@ private:
     QLabel *_noteEditLineNumberLabel;
     QPushButton *_readOnlyButton;
     QPushButton *_leaveDistractionFreeModeButton;
+    QPushButton *_leaveFullScreenModeButton;
     QToolBar *_formattingToolbar;
     QToolBar *_customActionToolbar;
     QToolBar *_insertingToolbar;
@@ -597,14 +712,15 @@ private:
     QToolBar *_quitToolbar;
     bool _noteViewIsRegenerated;
     QHash<int, NoteHistoryItem> _activeNoteFolderNotePositions;
+    QHash<QString, QString> _workspaceNameUuidMap;
     bool _searchLineEditFromCompleter;
     bool _isNotesDirectoryWasModifiedDisabled;
     bool _isNotesWereModifiedDisabled;
     bool _isDefaultShortcutInitialized;
     QList<QShortcut *> _menuShortcuts;
     bool _showNotesFromAllNoteSubFolders;
-    QList<int> _buildNotesIndexBeforeNoteIdList;
-    QList<int> _buildNotesIndexBeforeNoteSubFolderIdList;
+    QVector<int> _buildNotesIndexBeforeNoteIdList;
+    QVector<int> _buildNotesIndexBeforeNoteSubFolderIdList;
     QList<int> _buildNotesIndexAfterNoteIdList;
     QList<int> _buildNotesIndexAfterNoteSubFolderIdList;
     QScrollArea *_noteTagButtonScrollArea;
@@ -631,13 +747,16 @@ private:
     QWidget *_logDockTitleBarWidget;
     QWidget *_scriptingDockTitleBarWidget;
     QComboBox *_workspaceComboBox;
+    QFrame *_noteFolderDockWidgetFrame;
+    bool _useNoteFolderButtons;
     bool _noteFolderDockWidgetWasVisible;
     bool _noteSubFolderDockWidgetVisible;
+    bool _closeEventWasFired;
     ActionDialog *_actionDialog;
     TodoDialog *_todoDialog;
     IssueAssistantDialog *_issueAssistantDialog;
-    OrphanedImagesDialog *_orphanedImagesDialog;
-    OrphanedAttachmentsDialog *_orphanedAttachmentsDialog;
+    StoredImagesDialog *_storedImagesDialog;
+    StoredAttachmentsDialog *_storedAttachmentsDialog;
     SettingsDialog *_settingsDialog;
     bool _noteExternallyRemovedCheckEnabled;
     QList<QAction *> _noteTextEditContextMenuActions;
@@ -647,6 +766,25 @@ private:
     bool _noteEditIsCentralWidget;
     bool _lastNoteSelectionWasMultiple;
     WebSocketServerService *_webSocketServerService;
+    WebAppClientService *_webAppClientService;
+    QActionGroup *_languageGroup;
+    QActionGroup *_spellBackendGroup;
+    bool _brokenTagNoteLinksRemoved = false;
+    const QIcon _tagIcon = QIcon::fromTheme(
+        QStringLiteral("tag"),
+        QIcon(QStringLiteral(":/icons/breeze-qownnotes/16x16/tag.svg")));
+    const QIcon _folderIcon = QIcon::fromTheme(
+        QStringLiteral("folder"),
+        QIcon(QStringLiteral(":icons/breeze-qownnotes/16x16/folder.svg")));
+    const QIcon _noteIcon = QIcon::fromTheme(
+        QStringLiteral("text-x-generic"),
+        QIcon(":icons/breeze-qownnotes/16x16/text-x-generic.svg"));
+    QList<QHotkey *> _globalShortcuts;
+    int _lastNoteId = 0;
+    bool _scriptUpdateFound = false;
+    bool _isMaximizedBeforeFullScreen = false;
+    bool _isMinimizedBeforeFullScreen = false;
+    CommandBar* _commandBar;
 
     void createSystemTrayIcon();
 
@@ -658,11 +796,9 @@ private:
 
     QString selectOwnCloudNotesFolder();
 
-    void setCurrentNote(
-            Note note,
-            bool updateNoteText = true,
-            bool updateSelectedNote = true,
-            bool addPreviousNoteToHistory = true);
+    void setCurrentNote(Note note, bool updateNoteText = true,
+                        bool updateSelectedNote = true,
+                        bool addPreviousNoteToHistory = true);
 
     void removeCurrentNote();
 
@@ -673,33 +809,31 @@ private:
     int openNoteDiffDialog(Note changedNote);
 
     void setNoteTextFromNote(Note *note, bool updateNoteTextViewOnly = false,
-                             bool ignorePreviewVisibility = false);
+                             bool ignorePreviewVisibility = false,
+                             bool allowRestoreCursorPosition = false);
 
     void loadNoteFolderListMenu();
 
-    void storeRecentNoteFolder(QString addFolderName, QString removeFolderName);
+    void storeRecentNoteFolder(const QString &addFolderName,
+                               const QString &removeFolderName);
 
     void storeSettings();
 
     void removeSelectedNotes();
 
-    void moveSelectedNotesToFolder(QString destinationFolder);
-
-    void copySelectedNotesToFolder(QString destinationFolder);
-
     void selectAllNotes();
 
     void updateCurrentFolderTooltip();
 
-    void handleTextNoteLinking();
+    void handleTextNoteLinking(int page = 0);
 
     void updateNoteTextFromDisk(Note note);
 
     void makeCurrentNoteFirstInNoteList();
 
-    void readSettingsFromSettingsDialog();
+    void readSettingsFromSettingsDialog(const bool isAppLaunch = false);
 
-    void setCurrentNoteFromHistoryItem(NoteHistoryItem item);
+    void setCurrentNoteFromHistoryItem(const NoteHistoryItem &item);
 
     bool prepareExportNoteAsPDFPrinter(QPrinter *printer);
 
@@ -711,15 +845,20 @@ private:
 
     void exportNoteAsPDF(QTextEdit *textEdit);
 
+    void exportNoteAsPDF(QTextDocument *doc);
+
     void printNote(QTextEdit *textEdit);
 
-    void updateEncryptNoteButtons();
+    void printTextDocument(QTextDocument *textDocument);
 
-    void askForEncryptedNotePasswordIfNeeded(QString additionalText = "");
+    void updateNoteEncryptionUI();
+
+    void askForEncryptedNotePasswordIfNeeded(
+        const QString &additionalText = QString());
 
     void showAppMetricsNotificationIfNeeded();
 
-    void resetCurrentNote();
+    void resetCurrentNote(bool goToTop = true);
 
     void setupNoteBookmarkShortcuts();
 
@@ -727,21 +866,23 @@ private:
 
     void gotoNextNote();
 
+    void activateContextMenu();
+
     void gotoPreviousNote();
 
-    void setDistractionFreeMode(bool enabled = true);
+    void setDistractionFreeMode(const bool enabled = true);
 
-    void changeDistractionFreeMode(bool enabled);
+    void changeDistractionFreeMode(const bool enabled);
 
-    bool insertMedia(QFile *file);
+    bool insertMedia(QFile *file, QString title = QString());
 
     int currentNoteLineNumber();
 
-    bool isValidMediaFile(QFile *file);
+    static bool isValidMediaFile(QFile *file);
 
-    bool isValidNoteFile(QFile *file);
+    static bool isValidNoteFile(QFile *file);
 
-    bool isInDistractionFreeMode();
+    static bool isInDistractionFreeMode();
 
     void removeSelectedTags();
 
@@ -749,6 +890,8 @@ private:
 
     void reloadCurrentNoteTags();
 
+    void highlightCurrentNoteTagsInTagTree();
+
     void filterNotesBySearchLineEditText();
 
     void filterNotes(bool searchForText = true);
@@ -757,26 +900,29 @@ private:
 
     void initStyling();
 
-    void tagSelectedNotes(Tag tag);
+    void tagSelectedNotes(const Tag &tag);
 
-    bool isMarkdownViewEnabled();
+    static bool isMarkdownViewEnabled();
 
-    void removeTagFromSelectedNotes(Tag tag);
+    void removeTagFromSelectedNotes(const Tag &tag);
 
     bool isNoteEditPaneEnabled();
 
     void initToolbars();
 
-    void buildTagTreeForParentItem(QTreeWidgetItem *parent = 0, bool topLevel = false);
+    void buildTagTreeForParentItem(QTreeWidgetItem *parent = nullptr,
+                                   bool topLevel = false);
 
-    void buildTagMoveMenuTree(QMenu *parentMenu,
-                              int parentTagId = 0);
+    void buildTagMoveMenuTree(QMenu *parentMenu, int parentTagId = 0);
 
     void buildBulkNoteTagMenuTree(QMenu *parentMenu, int parentTagId = 0);
 
-    QTreeWidgetItem *addTagToTagTreeWidget(QTreeWidgetItem *parent, Tag tag);
+    QTreeWidgetItem *addTagToTagTreeWidget(QTreeWidgetItem *parent,
+                                           const TagHeader &tag);
 
-    bool jumpToNoteName(QString name);
+    bool jumpToNoteName(const QString &name);
+
+    bool jumpToNoteHistoryItem(const NoteHistoryItem &historyItem);
 
     void initScriptingEngine();
 
@@ -790,17 +936,12 @@ private:
 
     bool isToolbarVisible();
 
-    void setTreeWidgetItemToolTipForNote(QTreeWidgetItem *item, Note *note,
-                                         QDateTime *overrideFileLastModified
-                                         = 0);
-
     QTreeWidgetItem *firstVisibleNoteTreeWidgetItem();
 
     QTreeWidgetItem *addNoteSubFolderToTreeWidget(
-            QTreeWidgetItem *parentItem,
-            NoteSubFolder noteSubFolder);
+        QTreeWidgetItem *parentItem, const NoteSubFolder &noteSubFolder);
 
-    void buildNoteSubFolderTreeForParentItem(QTreeWidgetItem *parent = 0);
+    void buildNoteSubFolderTreeForParentItem(QTreeWidgetItem *parent = nullptr);
 
     void setupNoteSubFolders();
 
@@ -808,13 +949,12 @@ private:
 
     void updateNoteDirectoryWatcher();
 
-    bool addNoteToNoteTreeWidget(Note note);
+    bool addNoteToNoteTreeWidget(const Note &note,
+                                 QTreeWidgetItem *parent = nullptr);
 
-    void removeSelectedNoteSubFolders();
+    void removeSelectedNoteSubFolders(QTreeWidget *treeWidget);
 
-    bool createNewNoteSubFolder(QString folderName = "");
-
-    QTreeWidgetItem *findNoteInNoteTreeWidget(Note note);
+    QTreeWidgetItem *findNoteInNoteTreeWidget(const Note &note);
 
     void jumpToNoteOrCreateNew(bool disableLoadNoteDirectoryList = false);
 
@@ -825,13 +965,16 @@ private:
     void buildBulkNoteSubFolderMenuTree(QMenu *parentMenu, bool doCopy = true,
                                         int parentNoteSubFolderId = 0);
 
-    void moveSelectedNotesToNoteSubFolder(NoteSubFolder noteSubFolder);
+    void buildBulkNoteFolderSubFolderMenuTree(
+        QMenu *parentMenu, bool doCopy, const QString &parentNoteSubFolderPath,
+        bool isRoot = true);
 
-    void copySelectedNotesToNoteSubFolder(NoteSubFolder noteSubFolder);
+    void moveSelectedNotesToNoteSubFolder(const NoteSubFolder &noteSubFolder);
 
-    void createNewNote(QString noteName = "", bool withNameAppend = true);
+    void copySelectedNotesToNoteSubFolder(const NoteSubFolder &noteSubFolder);
 
-    bool selectedNotesHaveTags();
+    void createNewNote(QString noteName = QString(),
+                       bool withNameAppend = true);
 
     void initTagButtonScrollArea();
 
@@ -841,7 +984,7 @@ private:
 
     void initTreeWidgetItemHeight();
 
-    void updateTreeWidgetItemHeight(QTreeWidget *treeWidget, int height);
+    static void updateTreeWidgetItemHeight(QTreeWidget *treeWidget, int height);
 
     bool solveEquationInNoteTextEdit(double &returnValue);
 
@@ -853,14 +996,12 @@ private:
 
     bool createNewWorkspace(QString name);
 
-    QString currentWorkspaceUuid();
+    static QString currentWorkspaceUuid();
 
     void storeCurrentWorkspace();
 
     void initWorkspaceComboBox();
 
-    QStringList getWorkspaceUuidList();
-
     void updateWindowToolbar();
 
     void restoreToolbars();
@@ -873,7 +1014,10 @@ private:
 
     void assignColorToTagItem(QTreeWidgetItem *item);
 
-    void handleTreeWidgetItemTagColor(QTreeWidgetItem *item, Tag &tag) const;
+    static void handleTreeWidgetItemTagColor(QTreeWidgetItem *item,
+                                             const Tag &tag);
+    static void handleTreeWidgetItemTagColor(QTreeWidgetItem *item,
+                                             int tag);
 
     void disableColorOfTagItem(QTreeWidgetItem *item);
 
@@ -881,7 +1025,7 @@ private:
 
     void handleNoteTreeTagColoringForNote(const Note &note);
 
-    bool showRestartNotificationIfNeeded();
+    bool showRestartNotificationIfNeeded(bool force = false);
 
     void unsetCurrentNote();
 
@@ -891,15 +1035,15 @@ private:
 
     void storeTagTreeWidgetExpandState() const;
 
-    void startAppVersionTest() const;
+    static void startAppVersionTest();
 
     bool showNotesFromAllNoteSubFolders();
 
     void selectAllNotesInNoteSubFolderTreeWidget() const;
 
-    bool insertAttachment(QFile *file);
+    bool insertAttachment(QFile *file, const QString &title = QString());
 
-    Qt::SortOrder toQtOrder(int order);
+    static Qt::SortOrder toQtOrder(int order);
 
     void updatePanelsSortOrder();
 
@@ -907,46 +1051,78 @@ private:
 
     void selectAllNotesInTagTreeWidget() const;
 
-    void handleScriptingNoteTagging(Note note, QString tagName,
+    void handleScriptingNoteTagging(Note note, const Tag &tag,
                                     bool doRemove = false,
                                     bool triggerPostMethods = true);
 
     void handleScriptingNotesTagUpdating();
 
-    void handleScriptingNotesTagRenaming(QString oldTagName, QString newTagName);
+    void handleScriptingNotesTagRenaming(const Tag &tag,
+                                         const QString &newTagName);
 
-    void handleScriptingNotesTagRemoving(QString tagName,
+    void handleScriptingNotesTagRemoving(const Tag &tag,
                                          bool forBulkOperation = false);
 
     void directoryWatcherWorkaround(bool isNotesDirectoryWasModifiedDisabled,
                                     bool alsoHandleNotesWereModified = false);
 
-    void setMenuEnabled(QMenu* menu, bool enabled);
+    static void setMenuEnabled(QMenu *menu, bool enabled);
 
-    bool undoFormatting(QString formatter);
+    bool undoFormatting(const QString &formatter);
 
-    void applyFormatter(QString formatter);
+    void applyFormatter(const QString &formatter);
 
     bool isNoteTextSelected();
 
     void noteTextEditCustomContextMenuRequested(
-            QOwnNotesMarkdownTextEdit *noteTextEdit, const QPoint &pos);
+        QOwnNotesMarkdownTextEdit *noteTextEdit, const QPoint pos);
 
     void updateNoteTextEditReadOnly();
 
     int getSelectedNotesCount() const;
 
-    void updateNoteTreeWidgetItem(Note &note,
+    void updateNoteTreeWidgetItem(const Note &note,
                                   QTreeWidgetItem *noteItem = nullptr);
 
     void initFakeVim(QOwnNotesMarkdownTextEdit *noteTextEdit);
 
-    void openNotesContextMenu(const QPoint &globalPos,
-            bool multiNoteMenuEntriesOnly = false);
+    void openNotesContextMenu(const QPoint globalPos,
+                              bool multiNoteMenuEntriesOnly = false);
+
+    void openNoteSubFolderContextMenu(const QPoint globalPos,
+                                      QTreeWidget *treeWidget);
 
     void updateCurrentNoteTextHash();
 
     void centerAndResize();
 
     void forceRegenerateNotePreview();
+
+    void removeConflictedNotesDatabaseCopies();
+
+    void doSearchInNote(QString searchText);
+
+    void insertNoteText(const QString &text);
+
+    void handleNoteTextChanged();
+
+    void loadDictionaryNames();
+
+    void loadSpellingBackends();
+
+    QTextDocument *getDocumentForPreviewExport();
+
+    void noteTextEditTextWasUpdated();
+    void removeNoteFromNoteTreeWidget(Note &note) const;
+    void initGlobalKeyboardShortcuts();
+    void clearNoteDirectoryWatcher();
+    void resizeTagTreeWidgetColumnToContents() const;
+    void resizeNoteSubFolderTreeWidgetColumnToContents() const;
+    void updateCurrentTabData(const Note &note) const;
+    bool jumpToTab(const Note &note) const;
+    void closeOrphanedTabs() const;
+    void removeNoteTab(int index) const;
+    void automaticScriptUpdateCheck();
+
+    void updateJumpToActionsAvailability();
 };
