@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,13 +12,16 @@
  *
  */
 
+#include "git.h"
+
+#include <entities/notefolder.h>
+
 #include <QDebug>
 #include <QProcess>
-#include <entities/notefolder.h>
 #include <QtCore/QSettings>
-#include "git.h"
-#include "misc.h"
 
+#include "gui.h"
+#include "misc.h"
 
 /**
  * Checks if the current note folder uses git
@@ -38,15 +41,16 @@ void Utils::Git::commitCurrentNoteFolder() {
         return;
     }
 
-    QProcess *process = new QProcess();
+    auto* process = new QProcess();
     process->setWorkingDirectory(NoteFolder::currentLocalPath());
 
-    if (!executeGitCommand("init", process) ||
-        !executeGitCommand("config commit.gpgsign false", process) ||
-        !executeGitCommand("add -A", process) ||
-        !executeGitCommand("commit -m \"QOwnNotes commit\"", process)) {
-        return;
+    if (!executeGitCommand(QStringList{"init"}, process) ||
+        !executeGitCommand(QStringList{"config", "commit.gpgsign", "false"}, process) ||
+        !executeGitCommand(QStringList{"add", "-A"}, process) ||
+        !executeGitCommand(QStringList{"commit", "-m", "QOwnNotes commit"}, process)) {
     }
+
+    delete (process);
 }
 
 /**
@@ -56,28 +60,39 @@ void Utils::Git::commitCurrentNoteFolder() {
  * @param process
  * @return
  */
-bool Utils::Git::executeCommand(QString command, QProcess *process) {
+bool Utils::Git::executeCommand(const QString& command, const QStringList& arguments,
+                                QProcess* process, bool withErrorDialog) {
     if (process == Q_NULLPTR) {
         process = new QProcess();
     }
 
-    process->start(command);
+    process->start(command, arguments);
 
     if (!process->waitForFinished()) {
-        qWarning() << "Command '" + command + "' failed";
+        qWarning() << "Command '" + command + "' (" << arguments << ") failed";
+
+        if (withErrorDialog) {
+            Utils::Gui::warning(
+                Q_NULLPTR, QObject::tr("Command failed!"),
+                QObject::tr("The command <code>%1</code> with arguments <code>%2</code> failed!")
+                    .arg(command, arguments.join(QStringLiteral(", "))),
+                "command-failed");
+        }
+
         return false;
     }
 
-//    QByteArray result = process->readAll();
+    //    QByteArray result = process->readAll();
 
-//    if (!result.isEmpty()) {
-//    qDebug() << "Result message by '" + command + "': " + result;
-//    }
+    //    if (!result.isEmpty()) {
+    //    qDebug() << "Result message by '" + command + "': " + result;
+    //    }
 
     QByteArray errorMessage = process->readAllStandardError();
 
     if (!errorMessage.isEmpty()) {
-        qWarning() << "Error message by '" + command + "': " + errorMessage;
+        qWarning() << "Error message by '" + command + "' (" << arguments
+                   << "): " + errorMessage;
     }
 
     return true;
@@ -90,8 +105,9 @@ bool Utils::Git::executeCommand(QString command, QProcess *process) {
  * @param process
  * @return
  */
-bool Utils::Git::executeGitCommand(QString arguments, QProcess *process) {
-    return executeCommand("\""+ gitCommand() + "\" " + arguments, process);
+bool Utils::Git::executeGitCommand(const QStringList& arguments, QProcess* process,
+                                   bool withErrorDialog) {
+    return executeCommand(gitCommand(), arguments, process, withErrorDialog);
 }
 
 /**
@@ -129,7 +145,7 @@ bool Utils::Git::hasLogCommand() {
  *
  * @param filePath
  */
-void Utils::Git::showLog(QString filePath) {
+void Utils::Git::showLog(const QString& filePath) {
     QSettings settings;
     QString gitLogCommand = settings.value("gitLogCommand").toString();
 
@@ -146,18 +162,17 @@ void Utils::Git::showLog(QString filePath) {
 
     QStringList parameters = QStringList();
 
+#ifdef Q_OS_WIN
+    // we are executing the full command with parameters directly
+    // using "cmd.exe /c" doesn't work
+    QString command = gitLogCommand;
+#else
     // we need a shell to be able to use the executable with the parameters
     // together
-#ifdef Q_OS_WIN
-    QString command = "cmd.exe";
-    parameters << "/c";
-#else
     QString command = "bash";
-    parameters << "-c";
+    parameters << "-c" << gitLogCommand;
 #endif
 
-    parameters << gitLogCommand;
-
     Utils::Misc::startDetachedProcess(command, parameters,
                                       NoteFolder::currentLocalPath());
 }
\ No newline at end of file
