@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,28 +12,29 @@
  *
  */
 
-#include <QColorDialog>
-#include <QDebug>
-#include <QTreeWidgetItem>
-#include <QSettings>
-#include <QInputDialog>
-#include <QUuid>
-#include <QTextEdit>
-#include <QMessageBox>
-#include <QFileDialog>
-#include <QKeyEvent>
-#include <QDesktopServices>
-#include <utils/misc.h>
+#include "fontcolorwidget.h"
+
 #include <dialogs/filedialog.h>
 #include <utils/gui.h>
-#include "fontcolorwidget.h"
+#include <utils/misc.h>
+
+#include <QColorDialog>
+#include <QDebug>
+#include <QDesktopServices>
+#include <QFileDialog>
+#include <QInputDialog>
+#include <QKeyEvent>
+#include <QMessageBox>
+#include <QSettings>
+#include <QTextEdit>
+#include <QTreeWidgetItem>
+#include <QUuid>
+
 #include "ui_fontcolorwidget.h"
 #include "utils/schema.h"
 
-
-FontColorWidget::FontColorWidget(QWidget *parent) :
-    QFrame(parent),
-    ui(new Ui::FontColorWidget) {
+FontColorWidget::FontColorWidget(QWidget* parent)
+    : QFrame(parent), ui(new Ui::FontColorWidget) {
     ui->setupUi(this);
 
     // initialize the schema selector
@@ -49,28 +50,39 @@ FontColorWidget::FontColorWidget(QWidget *parent) :
     // see: https://github.com/pbek/QOwnNotes/issues/503
     // see: https://bugreports.qt.io/browse/QTBUG-56565
 #ifdef Q_OS_MAC
-    #if (QT_VERSION < QT_VERSION_CHECK(5, 8, 0))
+#if (QT_VERSION < QT_VERSION_CHECK(5, 8, 0))
     ui->copySchemeButton->setEnabled(false);
-    ui->copySchemeButton->setToolTip("Disabled because of a Qt bug, see "
-                                "https://github.com/pbek/QOwnNotes/issues/503");
-    #endif
+    ui->copySchemeButton->setToolTip(
+        "Disabled because of a Qt bug, see "
+        "https://github.com/pbek/QOwnNotes/issues/503");
+#endif
 #endif
 
     // initialize the font selectors
-//    initFontSelectors();
+    //    initFontSelectors();
 
     // declare that we need to restart the application if certain settings
     // are changed
-    connect(ui->colorSchemeComboBox, SIGNAL(currentIndexChanged(int)),
-            this, SLOT(needRestart()));
-    connect(ui->foregroundColorCheckBox, SIGNAL(toggled(bool)),
-            this, SLOT(needRestart()));
-    connect(ui->backgroundColorCheckBox, SIGNAL(toggled(bool)),
-            this, SLOT(needRestart()));
-    connect(ui->foregroundColorButton, SIGNAL(clicked()),
-            this, SLOT(needRestart()));
-    connect(ui->backgroundColorButton, SIGNAL(clicked()),
-            this, SLOT(needRestart()));
+    connect(ui->colorSchemeComboBox, SIGNAL(currentIndexChanged(int)), this,
+            SLOT(needRestart()));
+    connect(ui->fontCheckBox, SIGNAL(toggled(bool)), this,
+            SLOT(needRestart()));
+    connect(ui->foregroundColorCheckBox, SIGNAL(toggled(bool)), this,
+            SLOT(needRestart()));
+    connect(ui->backgroundColorCheckBox, SIGNAL(toggled(bool)), this,
+            SLOT(needRestart()));
+    connect(ui->boldCheckBox, SIGNAL(toggled(bool)), this,
+            SLOT(needRestart()));
+    connect(ui->italicCheckBox, SIGNAL(toggled(bool)), this,
+            SLOT(needRestart()));
+    connect(ui->underlineCheckBox, SIGNAL(toggled(bool)), this,
+            SLOT(needRestart()));
+    connect(ui->foregroundColorButton, SIGNAL(clicked()), this,
+            SLOT(needRestart()));
+    connect(ui->backgroundColorButton, SIGNAL(clicked()), this,
+            SLOT(needRestart()));
+    connect(ui->fontComboBox, SIGNAL(currentFontChanged(QFont)), this,
+            SLOT(needRestart()));
 }
 
 /**
@@ -78,6 +90,7 @@ FontColorWidget::FontColorWidget(QWidget *parent) :
  */
 void FontColorWidget::initSchemaSelector() {
     ui->colorSchemeComboBox->clear();
+    ui->fontComboBox->setEnabled(false);
 
     //
     // load the default schemes
@@ -86,50 +99,52 @@ void FontColorWidget::initSchemaSelector() {
     _defaultSchemaKeys = Utils::Schema::schemaSettings->defaultSchemaKeys();
 
     QSettings settings;
-    QString currentSchemaKey = settings.value("Editor/CurrentSchemaKey",
-                                       _defaultSchemaKeys.length() > 0 ?
-                                       _defaultSchemaKeys[0] : "").toString();
+    QString currentSchemaKey =
+        settings
+            .value(QStringLiteral("Editor/CurrentSchemaKey"),
+                   _defaultSchemaKeys.length() > 0 ? _defaultSchemaKeys[0]
+                                                   : QString())
+            .toString();
     int index = 0;
     int currentIndex = 0;
 
-    Q_FOREACH(const QString& schemaKey, _defaultSchemaKeys) {
-            const QSettings& defaultSchemaSettings =
-                    Utils::Schema::schemaSettings->defaultSchemaSettings();
-            const QString& name = defaultSchemaSettings.value(
-                        schemaKey + "/Name").toString();
-            ui->colorSchemeComboBox->addItem(name, schemaKey);
+    Q_FOREACH (const QString& schemaKey, _defaultSchemaKeys) {
+        const QSettings& defaultSchemaSettings =
+            Utils::Schema::schemaSettings->defaultSchemaSettings();
+        const QString& name =
+            defaultSchemaSettings.value(schemaKey + "/Name").toString();
+        ui->colorSchemeComboBox->addItem(name, schemaKey);
 
-            if (currentSchemaKey == schemaKey) {
-                currentIndex = index;
-            }
+        if (currentSchemaKey == schemaKey) {
+            currentIndex = index;
+        }
 
-            index++;
+        index++;
     }
 
     //
     // load the custom schemes
     //
-    QStringList schemes = settings.value("Editor/ColorSchemes").toStringList();
-    Q_FOREACH(QString schemaKey, schemes) {
-            settings.beginGroup(schemaKey);
-            QString name = settings.value("Name").toString();
-            ui->colorSchemeComboBox->addItem(name, schemaKey);
-            settings.endGroup();
+    QStringList schemes =
+        settings.value(QStringLiteral("Editor/ColorSchemes")).toStringList();
+    Q_FOREACH (QString schemaKey, schemes) {
+        settings.beginGroup(schemaKey);
+        QString name = settings.value(QStringLiteral("Name")).toString();
+        ui->colorSchemeComboBox->addItem(name, schemaKey);
+        settings.endGroup();
 
-            if (currentSchemaKey == schemaKey) {
-                currentIndex = index;
-            }
+        if (currentSchemaKey == schemaKey) {
+            currentIndex = index;
+        }
 
-            index++;
+        index++;
     }
 
     // set the current color schema
     ui->colorSchemeComboBox->setCurrentIndex(currentIndex);
 }
 
-FontColorWidget::~FontColorWidget() {
-    delete ui;
-}
+FontColorWidget::~FontColorWidget() { delete ui; }
 
 /**
  * Sets a new foreground color
@@ -144,9 +159,9 @@ void FontColorWidget::on_foregroundColorButton_clicked() {
     }
 
     ui->foregroundColorButton->setStyleSheet(
-            QString("* {background: %1; border: none}").arg(color.name()));
+        QStringLiteral("* {background: %1; border: none}").arg(color.name()));
 
-    setSchemaValue(textSettingsKey("ForegroundColor"), color);
+    setSchemaValue(textSettingsKey(QStringLiteral("ForegroundColor")), color);
 
     // update the current or all text items, depending on the index
     updateTextItems(index);
@@ -165,9 +180,9 @@ void FontColorWidget::on_backgroundColorButton_clicked() {
     }
 
     ui->backgroundColorButton->setStyleSheet(
-            QString("* {background: %1; border: none}").arg(color.name()));
+        QStringLiteral("* {background: %1; border: none}").arg(color.name()));
 
-    setSchemaValue(textSettingsKey("BackgroundColor"), color);
+    setSchemaValue(textSettingsKey(QStringLiteral("BackgroundColor")), color);
 
     // update the current or all text items, depending on the index
     updateTextItems(index);
@@ -194,13 +209,31 @@ void FontColorWidget::updateTextItems(int index) {
 void FontColorWidget::initTextTreeWidgetItems() {
     addTextTreeWidgetItem(tr("Text preset"), Utils::Schema::TextPresetIndex);
     addTextTreeWidgetItem(tr("Emphasized text"), MarkdownHighlighter::Italic);
+    addTextTreeWidgetItem(tr("Underlined text"), MarkdownHighlighter::StUnderline);
     addTextTreeWidgetItem(tr("Strong text"), MarkdownHighlighter::Bold);
     addTextTreeWidgetItem(tr("Link"), MarkdownHighlighter::Link);
     addTextTreeWidgetItem(tr("Image"), MarkdownHighlighter::Image);
     addTextTreeWidgetItem(tr("Code (block)"), MarkdownHighlighter::CodeBlock);
     addTextTreeWidgetItem(tr("Code (inline)"),
                           MarkdownHighlighter::InlineCodeBlock);
+
+    addTextTreeWidgetItem(tr("Code (keyword)"),
+                          MarkdownHighlighter::CodeKeyWord);
+    addTextTreeWidgetItem(tr("Code (type)"), MarkdownHighlighter::CodeType);
+    addTextTreeWidgetItem(tr("Code (comment)"),
+                          MarkdownHighlighter::CodeComment);
+    addTextTreeWidgetItem(tr("Code (string)"), MarkdownHighlighter::CodeString);
+    addTextTreeWidgetItem(tr("Code (built in)"),
+                          MarkdownHighlighter::CodeBuiltIn);
+    addTextTreeWidgetItem(tr("Code (num literal)"),
+                          MarkdownHighlighter::CodeNumLiteral);
+    addTextTreeWidgetItem(tr("Code (other)"), MarkdownHighlighter::CodeOther);
+
     addTextTreeWidgetItem(tr("List item"), MarkdownHighlighter::List);
+    addTextTreeWidgetItem(tr("Checkbox unchecked"),
+                          MarkdownHighlighter::CheckBoxUnChecked);
+    addTextTreeWidgetItem(tr("Checkbox checked"),
+                          MarkdownHighlighter::CheckBoxChecked);
     addTextTreeWidgetItem(tr("Header, level 1"), MarkdownHighlighter::H1);
     addTextTreeWidgetItem(tr("Header, level 2"), MarkdownHighlighter::H2);
     addTextTreeWidgetItem(tr("Header, level 3"), MarkdownHighlighter::H3);
@@ -212,22 +245,30 @@ void FontColorWidget::initTextTreeWidgetItems() {
     addTextTreeWidgetItem(tr("Block quote"), MarkdownHighlighter::BlockQuote);
     addTextTreeWidgetItem(tr("Table"), MarkdownHighlighter::Table);
     addTextTreeWidgetItem(tr("(HTML) Comment"), MarkdownHighlighter::Comment);
-    addTextTreeWidgetItem(tr("Masked syntax", "text that will highlighted in "
-                                  "a way that it's barely visible"),
+    addTextTreeWidgetItem(tr("Masked syntax",
+                             "text that will highlighted in "
+                             "a way that it's barely visible"),
                           MarkdownHighlighter::MaskedSyntax);
     addTextTreeWidgetItem(tr("Current line background color"),
                           MarkdownHighlighter::CurrentLineBackgroundColor);
     addTextTreeWidgetItem(tr("Broken link"), MarkdownHighlighter::BrokenLink);
+    addTextTreeWidgetItem(tr("Trailing space"),
+                          MarkdownHighlighter::TrailingSpace);
+
+    // jump to the top of the list so that an item is selected
+    auto *event = new QKeyEvent(QEvent::KeyPress, Qt::Key_Home, Qt::NoModifier);
+    QApplication::postEvent(ui->textTreeWidget, event);
 }
 
-void FontColorWidget::addTextTreeWidgetItem(QString text, int index) {
-    QTreeWidgetItem *item = new QTreeWidgetItem();
+void FontColorWidget::addTextTreeWidgetItem(const QString& text, int index) {
+    auto* item = new QTreeWidgetItem();
     item->setText(0, text);
     item->setData(0, Qt::UserRole, index);
 
     if (index == Utils::Schema::TextPresetIndex) {
-        item->setToolTip(0, tr(
-                "This item will be used to preset colors for the other items"));
+        item->setToolTip(
+            0,
+            tr("This item will be used to preset colors for the other items"));
     }
 
     // update the styling of the text tree widget item
@@ -240,7 +281,7 @@ void FontColorWidget::addTextTreeWidgetItem(QString text, int index) {
  * Updates the schema edit frame for the currently selected text item
  */
 void FontColorWidget::updateSchemeEditFrame() {
-    QTreeWidgetItem *item = ui->textTreeWidget->currentItem();
+    QTreeWidgetItem* item = ui->textTreeWidget->currentItem();
 
     if (item == Q_NULLPTR) {
         // select a current item if none was selected
@@ -253,34 +294,46 @@ void FontColorWidget::updateSchemeEditFrame() {
     // check if we are not viewing a default schema
     ui->schemeEditFrame->setEnabled(!_currentSchemaIsDefault);
 
-    bool enabled = Utils::Schema::schemaSettings->getSchemaValue(
-            textSettingsKey("ForegroundColorEnabled")).toBool();
+    bool enabled = Utils::Schema::schemaSettings
+                       ->getSchemaValue(textSettingsKey(
+                           QStringLiteral("FontEnabled")))
+                       .toBool();
+    updateFontCheckBox(enabled);
+
+    enabled = Utils::Schema::schemaSettings
+                       ->getSchemaValue(textSettingsKey(
+                           QStringLiteral("ForegroundColorEnabled")))
+                       .toBool();
     updateForegroundColorCheckBox(enabled);
 
     QColor color = Utils::Schema::schemaSettings->getForegroundColor(index);
     ui->foregroundColorButton->setStyleSheet(
-            QString("* {background: %1; border: none;}").arg(color.name()));
+        QStringLiteral("* {background: %1; border: none;}").arg(color.name()));
 
-    enabled = Utils::Schema::schemaSettings->getSchemaValue(
-            textSettingsKey("BackgroundColorEnabled")).toBool();
+    enabled = Utils::Schema::schemaSettings
+                  ->getSchemaValue(
+                      textSettingsKey(QStringLiteral("BackgroundColorEnabled")))
+                  .toBool();
     updateBackgroundColorCheckBox(enabled);
 
     color = Utils::Schema::schemaSettings->getBackgroundColor(index);
     ui->backgroundColorButton->setStyleSheet(
-            QString("* {background: %1; border: none;}").arg(color.name()));
+        QStringLiteral("* {background: %1; border: none;}").arg(color.name()));
 
     bool isCurrentLineBackgroundColorIndex =
-            index == MarkdownHighlighter::HighlighterState::
-                     CurrentLineBackgroundColor;
+        index ==
+        MarkdownHighlighter::HighlighterState::CurrentLineBackgroundColor;
 
     ui->boldCheckBox->setVisible(index >= 0 &&
-                                         !isCurrentLineBackgroundColorIndex);
+                                 !isCurrentLineBackgroundColorIndex);
     ui->italicCheckBox->setVisible(index >= 0 &&
                                    !isCurrentLineBackgroundColorIndex);
     ui->underlineCheckBox->setVisible(index >= 0 &&
                                       !isCurrentLineBackgroundColorIndex);
     ui->fontSizeAdaptionSpinBox->setVisible(index >= 0 &&
                                             !isCurrentLineBackgroundColorIndex);
+    ui->fontCheckBox->setVisible(index >= 0 && !isCurrentLineBackgroundColorIndex);
+    ui->fontComboBox->setVisible(index >= 0 && !isCurrentLineBackgroundColorIndex);
     ui->foregroundColorCheckBox->setVisible(!isCurrentLineBackgroundColorIndex);
     ui->foregroundColorButton->setVisible(!isCurrentLineBackgroundColorIndex);
     ui->label->setVisible(!isCurrentLineBackgroundColorIndex);
@@ -288,31 +341,48 @@ void FontColorWidget::updateSchemeEditFrame() {
 
     if (index >= 0) {
         const QSignalBlocker blocker(ui->boldCheckBox);
-        Q_UNUSED(blocker);
+        Q_UNUSED(blocker)
 
         ui->boldCheckBox->setChecked(
-                Utils::Schema::schemaSettings->getSchemaValue(
-                        textSettingsKey("Bold")).toBool());
+            Utils::Schema::schemaSettings
+                ->getSchemaValue(textSettingsKey(QStringLiteral("Bold")))
+                .toBool());
 
         const QSignalBlocker blocker2(ui->italicCheckBox);
-        Q_UNUSED(blocker2);
+        Q_UNUSED(blocker2)
 
         ui->italicCheckBox->setChecked(
-                Utils::Schema::schemaSettings->getSchemaValue(
-                        textSettingsKey("Italic")).toBool());
+            Utils::Schema::schemaSettings
+                ->getSchemaValue(textSettingsKey(QStringLiteral("Italic")))
+                .toBool());
 
         const QSignalBlocker blocker3(ui->underlineCheckBox);
-        Q_UNUSED(blocker3);
+        Q_UNUSED(blocker3)
 
         ui->underlineCheckBox->setChecked(
-                Utils::Schema::schemaSettings->getSchemaValue(
-                        textSettingsKey("Underline")).toBool());
+            Utils::Schema::schemaSettings
+                ->getSchemaValue(textSettingsKey(QStringLiteral("Underline")))
+                .toBool());
 
         const QSignalBlocker blocker4(ui->fontSizeAdaptionSpinBox);
-        Q_UNUSED(blocker4);
+        Q_UNUSED(blocker4)
 
-        ui->fontSizeAdaptionSpinBox->setValue(Utils::Schema::schemaSettings->getSchemaValue(
-                        textSettingsKey("FontSizeAdaption"), 100).toInt());
+        ui->fontSizeAdaptionSpinBox->setValue(
+            Utils::Schema::schemaSettings
+                ->getSchemaValue(
+                    textSettingsKey(QStringLiteral("FontSizeAdaption")), 100)
+                .toInt());
+
+        const QSignalBlocker blocker5(ui->fontComboBox);
+        Q_UNUSED(blocker5)
+
+        QFont font = Utils::Schema::schemaSettings
+             ->getSchemaValue(
+             textSettingsKey(QStringLiteral("Font")),
+                     Utils::Schema::schemaSettings->getEditorTextFont())
+             .value<QFont>();
+
+        ui->fontComboBox->setCurrentFont(font);
     }
 }
 
@@ -323,7 +393,8 @@ void FontColorWidget::updateSchemeEditFrame() {
  * @param item
  * @return
  */
-QString FontColorWidget::textSettingsKey(QString key, QTreeWidgetItem *item) {
+QString FontColorWidget::textSettingsKey(const QString& key,
+                                         QTreeWidgetItem* item) {
     return Utils::Schema::textSettingsKey(key, textSettingsIndex(item));
 }
 
@@ -333,7 +404,7 @@ QString FontColorWidget::textSettingsKey(QString key, QTreeWidgetItem *item) {
  * @param item
  * @return
  */
-int FontColorWidget::textSettingsIndex(QTreeWidgetItem *item) {
+int FontColorWidget::textSettingsIndex(QTreeWidgetItem* item) {
     if (item == Q_NULLPTR) {
         item = ui->textTreeWidget->currentItem();
     }
@@ -348,13 +419,13 @@ int FontColorWidget::textSettingsIndex(QTreeWidgetItem *item) {
  * @param key
  * @param value
  */
-void FontColorWidget::setSchemaValue(QString key, QVariant value,
+void FontColorWidget::setSchemaValue(const QString& key, const QVariant& value,
                                      QString schemaKey) {
     if (schemaKey.isEmpty()) {
         schemaKey = _currentSchemaKey;
     }
 
-    QSettings(settings);
+    QSettings settings;
     settings.beginGroup(schemaKey);
     return settings.setValue(key, value);
 }
@@ -372,7 +443,8 @@ void FontColorWidget::on_colorSchemeComboBox_currentIndexChanged(int index) {
     ui->schemeEditFrame->setEnabled(!_currentSchemaIsDefault);
 
     QSettings settings;
-    settings.setValue("Editor/CurrentSchemaKey", _currentSchemaKey);
+    settings.setValue(QStringLiteral("Editor/CurrentSchemaKey"),
+                      _currentSchemaKey);
 
     updateSchemeEditFrame();
 
@@ -386,11 +458,29 @@ void FontColorWidget::on_colorSchemeComboBox_currentIndexChanged(int index) {
 void FontColorWidget::updateAllTextItems() {
     // update all text items
     for (int i = 0; i < ui->textTreeWidget->topLevelItemCount(); i++) {
-        QTreeWidgetItem *item = ui->textTreeWidget->topLevelItem(i);
+        QTreeWidgetItem* item = ui->textTreeWidget->topLevelItem(i);
         updateTextItem(item);
     }
 }
 
+bool FontColorWidget::selectFirstLightSchema() {
+    if (ui->colorSchemeComboBox->count() >= 1) {
+        ui->colorSchemeComboBox->setCurrentIndex(0);
+        return true;
+    }
+
+    return false;
+}
+
+bool FontColorWidget::selectFirstDarkSchema() {
+    if (ui->colorSchemeComboBox->count() >= 2) {
+        ui->colorSchemeComboBox->setCurrentIndex(1);
+        return true;
+    }
+
+    return false;
+}
+
 /**
  * Updates the styling of certain items when the current text tree widget
  * item changes
@@ -399,9 +489,9 @@ void FontColorWidget::updateAllTextItems() {
  * @param previous
  */
 void FontColorWidget::on_textTreeWidget_currentItemChanged(
-        QTreeWidgetItem *current, QTreeWidgetItem *previous) {
-    Q_UNUSED(current);
-    Q_UNUSED(previous);
+    QTreeWidgetItem* current, QTreeWidgetItem* previous) {
+    Q_UNUSED(current)
+    Q_UNUSED(previous)
 
     // update the schema edit frame for the current item
     updateSchemeEditFrame();
@@ -414,7 +504,7 @@ void FontColorWidget::on_textTreeWidget_currentItemChanged(
  * Updates the styling of a text tree widget item
  * @param item
  */
-void FontColorWidget::updateTextItem(QTreeWidgetItem *item) {
+void FontColorWidget::updateTextItem(QTreeWidgetItem* item) {
     if (item == Q_NULLPTR) {
         item = ui->textTreeWidget->currentItem();
     }
@@ -429,6 +519,7 @@ void FontColorWidget::updateTextItem(QTreeWidgetItem *item) {
     QColor color = Utils::Schema::schemaSettings->getForegroundColor(index);
     QBrush brush = item->foreground(0);
     brush.setColor(color);
+    brush.setStyle(Qt::BrushStyle::SolidPattern);
     item->setForeground(0, brush);
 
     // set the background color
@@ -438,13 +529,16 @@ void FontColorWidget::updateTextItem(QTreeWidgetItem *item) {
     brush.setStyle(Qt::SolidPattern);
     item->setBackground(0, brush);
 
-    QFont font = Utils::Schema::schemaSettings->getEditorFont(index);
-    font.setBold(Utils::Schema::schemaSettings->getSchemaValue(
-            textSettingsKey("Bold", item)).toBool());
-    font.setItalic(Utils::Schema::schemaSettings->getSchemaValue(
-            textSettingsKey("Italic", item)).toBool());
-    font.setUnderline(Utils::Schema::schemaSettings->getSchemaValue(
-                    textSettingsKey("Underline", item)).toBool());
+    QFont font = Utils::Schema::schemaSettings->getFont(index);
+    font.setBold(Utils::Schema::schemaSettings
+                     ->getSchemaValue(textSettingsKey("Bold", item))
+                     .toBool());
+    font.setItalic(Utils::Schema::schemaSettings
+                       ->getSchemaValue(textSettingsKey("Italic", item))
+                       .toBool());
+    font.setUnderline(Utils::Schema::schemaSettings
+                          ->getSchemaValue(textSettingsKey("Underline", item))
+                          .toBool());
 
     // adapt the font size
     Utils::Schema::schemaSettings->adaptFontSize(index, font);
@@ -457,27 +551,28 @@ void FontColorWidget::updateTextItem(QTreeWidgetItem *item) {
  */
 void FontColorWidget::on_copySchemeButton_clicked() {
     // ask the user for a new schema name
-    QString name = QInputDialog::getText(this, tr("Copy color schema"),
-                          tr("Color schema name"), QLineEdit::Normal,
-                          ui->colorSchemeComboBox->currentText() + " (" +
+    QString name =
+        QInputDialog::getText(this, tr("Copy color schema"),
+                              tr("Color schema name"), QLineEdit::Normal,
+                              ui->colorSchemeComboBox->currentText() + " (" +
                                   tr("Copy", "as noun") + ")");
 
     if (name.isEmpty()) {
         return;
     }
 
-    const QStringList& keys = Utils::Schema::schemaSettings->getSchemaKeys(_currentSchemaKey);
-    QString uuid = QUuid::createUuid().toString();
-    uuid.replace("{", "").replace("}", "");
+    const QStringList& keys =
+        Utils::Schema::schemaSettings->getSchemaKeys(_currentSchemaKey);
+    QString uuid = Utils::Misc::createUuidString();
     _currentSchemaKey = "EditorColorSchema-" + uuid;
 
     // store the new color schema data
-    Q_FOREACH(const QString& key, keys) {
-            QVariant value = key == "Name" ?
-                             QVariant(name) :
-                             Utils::Schema::schemaSettings->getSchemaValue(key);
-            setSchemaValue(key, value, _currentSchemaKey);
-        }
+    Q_FOREACH (const QString& key, keys) {
+        QVariant value =
+            key == "Name" ? QVariant(name)
+                          : Utils::Schema::schemaSettings->getSchemaValue(key);
+        setSchemaValue(key, value, _currentSchemaKey);
+    }
 
     // add the new color schema to the color schemes list in the settings
     QSettings settings;
@@ -499,13 +594,13 @@ void FontColorWidget::selectLastSchema() {
 
 #ifdef Q_OS_MAC
     // under OS X we have to use a workaround to select the newly created schema
-    QKeyEvent *event = new QKeyEvent(QEvent::KeyPress, Qt::Key_End,
-                                     Qt::NoModifier);
+    QKeyEvent* event =
+        new QKeyEvent(QEvent::KeyPress, Qt::Key_End, Qt::NoModifier);
     QApplication::postEvent(ui->colorSchemeComboBox, event);
 #else
     // set the index to the (new) last item
-    ui->colorSchemeComboBox->setCurrentIndex(
-            ui->colorSchemeComboBox->count() - 1);
+    ui->colorSchemeComboBox->setCurrentIndex(ui->colorSchemeComboBox->count() -
+                                             1);
 #endif
 }
 
@@ -526,7 +621,7 @@ void FontColorWidget::on_foregroundColorCheckBox_toggled(bool checked) {
 
 void FontColorWidget::updateForegroundColorCheckBox(bool checked, bool store) {
     const QSignalBlocker blocker(ui->foregroundColorCheckBox);
-    Q_UNUSED(blocker);
+    Q_UNUSED(blocker)
 
     ui->foregroundColorCheckBox->setChecked(checked);
     ui->foregroundColorButton->setEnabled(checked);
@@ -556,7 +651,7 @@ void FontColorWidget::on_backgroundColorCheckBox_toggled(bool checked) {
 
 void FontColorWidget::updateBackgroundColorCheckBox(bool checked, bool store) {
     const QSignalBlocker blocker(ui->backgroundColorCheckBox);
-    Q_UNUSED(blocker);
+    Q_UNUSED(blocker)
 
     ui->backgroundColorCheckBox->setChecked(checked);
     ui->backgroundColorButton->setEnabled(checked);
@@ -573,13 +668,12 @@ void FontColorWidget::updateBackgroundColorCheckBox(bool checked, bool store) {
  * Removes the current schema
  */
 void FontColorWidget::on_deleteSchemeButton_clicked() {
-    if (_currentSchemaKey == "") {
+    if (_currentSchemaKey.isEmpty()) {
         return;
     }
 
     if (Utils::Gui::question(
-            this,
-            tr("Remove schema"),
+            this, tr("Remove schema"),
             tr("Remove current schema? This cannot be undone!"),
             "remove-color-schema") != QMessageBox::Yes) {
         return;
@@ -599,7 +693,7 @@ void FontColorWidget::on_deleteSchemeButton_clicked() {
     initSchemaSelector();
 }
 
-void FontColorWidget::storeCheckBoxState(QString name, bool checked) {
+void FontColorWidget::storeCheckBoxState(const QString& name, bool checked) {
     if (!_currentSchemaIsDefault) {
         setSchemaValue(textSettingsKey(name), checked);
     }
@@ -649,13 +743,17 @@ void FontColorWidget::on_exportSchemeButton_clicked() {
             exportSettings.setValue("Export/SchemaKey", _currentSchemaKey);
 
             exportSettings.beginGroup(_currentSchemaKey);
-            const QStringList& keys = Utils::Schema::schemaSettings->getSchemaKeys(_currentSchemaKey);
+            const QStringList& keys =
+                Utils::Schema::schemaSettings->getSchemaKeys(_currentSchemaKey);
 
             // store the color schema data to the export settings
-            Q_FOREACH(const QString& key, keys) {
-                    QVariant value = Utils::Schema::schemaSettings->getSchemaValue(key);
-                    exportSettings.setValue(key, value);
-                }
+            Q_FOREACH (const QString& key, keys) {
+                QVariant value =
+                    Utils::Schema::schemaSettings->getSchemaValue(key);
+                exportSettings.setValue(key, value);
+            }
+
+            Utils::Misc::openFolderSelect(fileName);
         }
     }
 }
@@ -674,38 +772,37 @@ void FontColorWidget::on_importSchemeButton_clicked() {
     if (ret == QDialog::Accepted) {
         QStringList fileNames = dialog.selectedFiles();
         if (fileNames.count() > 0) {
-            Q_FOREACH(QString fileName, fileNames) {
-                    QSettings *settings = new QSettings();
-                    QSettings *importSettings =
-                            new QSettings(fileName, QSettings::IniFormat);
-                    QString schemaKey = importSettings->value(
-                            "Export/SchemaKey").toString();
+            Q_FOREACH (QString fileName, fileNames) {
+                auto* settings = new QSettings();
+                auto* importSettings =
+                    new QSettings(fileName, QSettings::IniFormat);
+                QString schemaKey =
+                    importSettings->value("Export/SchemaKey").toString();
 
-                    // create a new schema key for the import
-                    QString uuid = QUuid::createUuid().toString();
-                    uuid.replace("{", "").replace("}", "");
-                    _currentSchemaKey = "EditorColorSchema-" + uuid;
+                // create a new schema key for the import
+                QString uuid = Utils::Misc::createUuidString();
+                _currentSchemaKey = "EditorColorSchema-" + uuid;
 
-                    QStringList schemes = settings->value(
-                            "Editor/ColorSchemes").toStringList();
-                    schemes << _currentSchemaKey;
-                    settings->setValue("Editor/ColorSchemes", schemes);
-                    settings->setValue("Editor/CurrentSchemaKey",
-                                       _currentSchemaKey);
+                QStringList schemes =
+                    settings->value("Editor/ColorSchemes").toStringList();
+                schemes << _currentSchemaKey;
+                settings->setValue("Editor/ColorSchemes", schemes);
+                settings->setValue("Editor/CurrentSchemaKey",
+                                   _currentSchemaKey);
 
-                    settings->beginGroup(_currentSchemaKey);
-                    importSettings->beginGroup(schemaKey);
-                    QStringList keys = importSettings->allKeys();
+                settings->beginGroup(_currentSchemaKey);
+                importSettings->beginGroup(schemaKey);
+                QStringList keys = importSettings->allKeys();
 
-                    // store the color schema data to the settings
-                    Q_FOREACH(QString key, keys) {
-                            QVariant value = importSettings->value(key);
-                            settings->setValue(key, value);
-                        }
-
-                    // select the last schema
-                    selectLastSchema();
+                // store the color schema data to the settings
+                Q_FOREACH (QString key, keys) {
+                    QVariant value = importSettings->value(key);
+                    settings->setValue(key, value);
                 }
+
+                // select the last schema
+                selectLastSchema();
+            }
         }
     }
 }
@@ -717,10 +814,10 @@ void FontColorWidget::initFontSelectors() {
     QTextEdit textEdit;
     QFont font = textEdit.font();
     QSettings settings;
-    QString fontString = settings.value(
-            "MainWindow/noteTextEdit.font").toString();
+    QString fontString =
+        settings.value("MainWindow/noteTextEdit.font").toString();
 
-    if (fontString != "") {
+    if (!fontString.isEmpty()) {
         // set the note text edit font
         font.fromString(fontString);
     } else {
@@ -751,17 +848,47 @@ void FontColorWidget::on_fontSizeAdaptionSpinBox_valueChanged(int value) {
  * Opens a new GitHub issue to share a schema
  */
 void FontColorWidget::on_shareSchemaPushButton_clicked() {
-    QDesktopServices::openUrl(
-            QUrl("https://github.com/pbek/QOwnNotes/issues/new?title=" +
-                   QUrl::toPercentEncoding("New editor schema: <schema-name>") +
-                   "&body=" + QUrl::toPercentEncoding(
-                    "I want to submit a new editor schema.\n\n"
-                            "(upload your schema)")));
+    QDesktopServices::openUrl(QUrl(
+        "https://github.com/pbek/QOwnNotes/issues/new?title=" +
+        QUrl::toPercentEncoding("New editor schema: <schema-name>") + "&body=" +
+        QUrl::toPercentEncoding("I want to submit a new editor schema.\n\n"
+                                "(upload your schema)")));
 }
 
 /**
  * Declares that we need a restart
  */
-void FontColorWidget::needRestart() {
-    Utils::Misc::needRestart();
+void FontColorWidget::needRestart() { Utils::Misc::needRestart(); }
+
+void FontColorWidget::on_fontCheckBox_toggled(bool checked) {
+    updateFontCheckBox(checked, true);
+
+    // update the current or all text items, depending on the index
+    updateTextItems(textSettingsIndex());
+
+    // update the scheme edit frame
+    updateSchemeEditFrame();
+
+}
+
+void FontColorWidget::updateFontCheckBox(bool checked, bool store) {
+    const QSignalBlocker blocker(ui->fontCheckBox);
+    Q_UNUSED(blocker)
+
+    ui->fontCheckBox->setChecked(checked);
+    ui->fontComboBox->setEnabled(checked);
+
+    // update the styling of the current text tree widget item
+    updateTextItem();
+
+    if (store && !_currentSchemaIsDefault) {
+        setSchemaValue(textSettingsKey("FontEnabled"), checked);
+    }
+}
+
+void FontColorWidget::on_fontComboBox_currentFontChanged(const QFont &f) {
+    setSchemaValue(textSettingsKey("Font"), f);
+
+    // update the styling of the current text tree widget item
+    updateTextItem();
 }
