@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,17 +13,17 @@
 
 #pragma once
 
-#include <QWidget>
-#include <QEvent>
 #include <QLineEdit>
+#include <QWidget>
 
-class LineEdit : public QLineEdit
-{
-Q_OBJECT
+class QEvent;
 
-public:
+class LineEdit : public QLineEdit {
+    Q_OBJECT
+
+   public:
     explicit LineEdit(QWidget *parent = nullptr);
 
-protected:
+   protected:
     bool eventFilter(QObject *obj, QEvent *event);
 };
