@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,18 +14,17 @@
 
 #pragma once
 
-#include <QFrame>
 #include <QEvent>
+#include <QFrame>
 
 namespace Ui {
 class LogWidget;
 }
 
-class LogWidget : public QFrame
-{
+class LogWidget : public QFrame {
     Q_OBJECT
 
-public:
+   public:
     enum LogType {
         DebugLogType,
         InfoLogType,
@@ -40,29 +39,28 @@ public:
     ~LogWidget();
     static LogWidget *instance();
     static LogWidget *createInstance(QWidget *parent);
-    static void logMessageOutput(
-            QtMsgType type,
-            const QMessageLogContext &context,
-            const QString &msg);
+    static void logMessageOutput(QtMsgType type,
+                                 const QMessageLogContext &context,
+                                 const QString &msg);
     bool eventFilter(QObject *obj, QEvent *event);
-    QString getLogText();
+    QString getLogText() const;
 
-public slots:
-    void log(LogWidget::LogType logType, QString text);
+   public slots:
+    void log(LogWidget::LogType logType, const QString &text);
 
-private slots:
+   private slots:
     void storeSettings() const;
 
     void on_clearButton_clicked();
 
-    void on_logTextEdit_customContextMenuRequested(const QPoint &pos);
+    void on_logTextEdit_customContextMenuRequested(QPoint pos);
 
     void onDestroyed(QObject *obj = Q_NULLPTR);
 
-private:
+   private:
     Ui::LogWidget *ui;
 
     static QString logTypeText(LogType logType);
 
-    static void logToFileIfAllowed(LogType logType, QString msg);
+    static void logToFileIfAllowed(LogType logType, const QString &msg);
 };
