@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,37 +13,55 @@
 
 #pragma once
 
-#include <QTextBrowser>
-#include <QResizeEvent>
 #include <widgets/qtexteditsearchwidget.h>
 
-class NotePreviewWidget : public QTextBrowser
-{
+#include <QPoint>
+#include <QResizeEvent>
+#include <QTextBrowser>
+
+class NotePreviewWidget : public QTextBrowser {
     Q_OBJECT
 
-public:
-    explicit NotePreviewWidget(QWidget *parent = 0);
+   public:
+    explicit NotePreviewWidget(QWidget *parent = nullptr);
     void initSearchFrame(QWidget *searchFrame, bool darkMode = false);
     QTextEditSearchWidget *searchWidget();
 
     void setHtml(const QString &text);
 
-protected:
+    void exportAsHTMLFile();
+
+   protected:
     QTextEditSearchWidget *_searchWidget;
     QWidget *_searchFrame;
+    QString _html;
 
-    void resizeEvent(QResizeEvent* event);
-    bool eventFilter(QObject *obj, QEvent *event);
+    void resizeEvent(QResizeEvent *event) override;
+    bool eventFilter(QObject *obj, QEvent *event) override;
 
     QStringList extractGifUrls(const QString &text) const;
     void animateGif(const QString &text);
 
-public slots:
+    void contextMenuEvent(QContextMenuEvent *event) override;
+
+    QVariant loadResource(int type, const QUrl& file) override;
+
+    bool lookupCache(const QString &key, QPixmap &pm);
+    void insertInCache(const QString &key, const QPixmap &pm);
+
+   public slots:
     void hide();
 
-signals:
+   signals:
     void resize(QSize size, QSize oldSize);
 
-private:
-    QList<QMovie*> _movies;
+   private:
+    QList<QMovie *> _movies;
+    QString _currentFile;
+
+    struct LargePixmap {
+        QString fileName;
+        QPixmap pixmap;
+    };
+    std::vector<LargePixmap> _largePixmapCache;
 };
