@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,33 +13,33 @@
  */
 
 #include "qtexteditsearchwidget.h"
-#include "ui_qtexteditsearchwidget.h"
+
+#include <QDebug>
 #include <QEvent>
 #include <QKeyEvent>
-#include <QDebug>
 
-QTextEditSearchWidget::QTextEditSearchWidget(QTextEdit *parent) :
-    QWidget(parent),
-    ui(new Ui::QTextEditSearchWidget)
-{
+#include "ui_qtexteditsearchwidget.h"
+
+QTextEditSearchWidget::QTextEditSearchWidget(QTextEdit *parent)
+    : QWidget(parent), ui(new Ui::QTextEditSearchWidget) {
     ui->setupUi(this);
     _textEdit = parent;
     hide();
 
-    QObject::connect(ui->closeButton, SIGNAL(clicked()),
-                     this, SLOT(deactivate()));
-    QObject::connect(ui->searchLineEdit, SIGNAL(textChanged(const QString &)),
-                     this, SLOT(searchLineEditTextChanged(const QString &)));
-    QObject::connect(ui->searchDownButton, SIGNAL(clicked()),
-                     this, SLOT(doSearchDown()));
-    QObject::connect(ui->searchUpButton, SIGNAL(clicked()),
-                     this, SLOT(doSearchUp()));
-    QObject::connect(ui->replaceToggleButton, SIGNAL(toggled(bool)),
-                     this, SLOT(setReplaceMode(bool)));
-    QObject::connect(ui->replaceButton, SIGNAL(clicked()),
-                     this, SLOT(doReplace()));
-    QObject::connect(ui->replaceAllButton, SIGNAL(clicked()),
-                     this, SLOT(doReplaceAll()));
+    QObject::connect(ui->closeButton, SIGNAL(clicked()), this,
+                     SLOT(deactivate()));
+    QObject::connect(ui->searchLineEdit, SIGNAL(textChanged(QString)), this,
+                     SLOT(searchLineEditTextChanged(QString)));
+    QObject::connect(ui->searchDownButton, SIGNAL(clicked()), this,
+                     SLOT(doSearchDown()));
+    QObject::connect(ui->searchUpButton, SIGNAL(clicked()), this,
+                     SLOT(doSearchUp()));
+    QObject::connect(ui->replaceToggleButton, SIGNAL(toggled(bool)), this,
+                     SLOT(setReplaceMode(bool)));
+    QObject::connect(ui->replaceButton, SIGNAL(clicked()), this,
+                     SLOT(doReplace()));
+    QObject::connect(ui->replaceAllButton, SIGNAL(clicked()), this,
+                     SLOT(doReplaceAll()));
 
     installEventFilter(this);
     ui->searchLineEdit->installEventFilter(this);
@@ -60,9 +60,7 @@ QTextEditSearchWidget::QTextEditSearchWidget(QTextEdit *parent) :
 #endif
 }
 
-QTextEditSearchWidget::~QTextEditSearchWidget() {
-    delete ui;
-}
+QTextEditSearchWidget::~QTextEditSearchWidget() { delete ui; }
 
 void QTextEditSearchWidget::setReplaceEnabled(bool enabled) {
     ui->replaceToggleButton->setVisible(enabled);
@@ -112,18 +110,18 @@ void QTextEditSearchWidget::setReplaceMode(bool enabled) {
 
 bool QTextEditSearchWidget::eventFilter(QObject *obj, QEvent *event) {
     if (event->type() == QEvent::KeyPress) {
-        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+        auto *keyEvent = static_cast<QKeyEvent *>(event);
 
         if (keyEvent->key() == Qt::Key_Escape) {
             deactivate();
             return true;
         } else if ((keyEvent->modifiers().testFlag(Qt::ShiftModifier) &&
-                  (keyEvent->key() == Qt::Key_Return)) ||
-                 (keyEvent->key() == Qt::Key_Up)) {
+                    (keyEvent->key() == Qt::Key_Return)) ||
+                   (keyEvent->key() == Qt::Key_Up)) {
             doSearchUp();
             return true;
         } else if ((keyEvent->key() == Qt::Key_Return) ||
-                 (keyEvent->key() == Qt::Key_Down)) {
+                   (keyEvent->key() == Qt::Key_Down)) {
             doSearchDown();
             return true;
         } else if (keyEvent->key() == Qt::Key_F3) {
@@ -131,10 +129,11 @@ bool QTextEditSearchWidget::eventFilter(QObject *obj, QEvent *event) {
             return true;
         }
 
-//        if ((obj == ui->replaceLineEdit) && (keyEvent->key() == Qt::Key_Tab)
-//                && ui->replaceToggleButton->isChecked()) {
-//            ui->replaceLineEdit->setFocus();
-//        }
+        //        if ((obj == ui->replaceLineEdit) && (keyEvent->key() ==
+        //        Qt::Key_Tab)
+        //                && ui->replaceToggleButton->isChecked()) {
+        //            ui->replaceLineEdit->setFocus();
+        //        }
 
         return false;
     }
@@ -147,13 +146,9 @@ void QTextEditSearchWidget::searchLineEditTextChanged(const QString &arg1) {
     doSearchDown();
 }
 
-void QTextEditSearchWidget::doSearchUp() {
-    doSearch(false);
-}
+void QTextEditSearchWidget::doSearchUp() { doSearch(false); }
 
-void QTextEditSearchWidget::doSearchDown() {
-    doSearch(true);
-}
+void QTextEditSearchWidget::doSearchDown() { doSearch(true); }
 
 bool QTextEditSearchWidget::doReplace(bool forAll) {
     if (_textEdit->isReadOnly()) {
@@ -169,8 +164,8 @@ bool QTextEditSearchWidget::doReplace(bool forAll) {
     int searchMode = ui->modeComboBox->currentIndex();
     if (searchMode == RegularExpressionMode) {
         QString text = c.selectedText();
-        text.replace(QRegExp(ui->searchLineEdit->text()),
-                             ui->replaceLineEdit->text());
+        text.replace(QRegularExpression(ui->searchLineEdit->text()),
+                     ui->replaceLineEdit->text());
         c.insertText(text);
     } else {
         c.insertText(ui->replaceLineEdit->text());
@@ -198,7 +193,8 @@ void QTextEditSearchWidget::doReplaceAll() {
     _textEdit->moveCursor(QTextCursor::Start);
 
     // replace until everything to the bottom is replaced
-    while (doSearch(true, false) && doReplace(true)) {}
+    while (doSearch(true, false) && doReplace(true)) {
+    }
 }
 
 /**
@@ -208,16 +204,15 @@ void QTextEditSearchWidget::doReplaceAll() {
 bool QTextEditSearchWidget::doSearch(bool searchDown, bool allowRestartAtTop) {
     QString text = ui->searchLineEdit->text();
 
-    if (text == "") {
-        ui->searchLineEdit->setStyleSheet("");
+    if (text.isEmpty()) {
+        ui->searchLineEdit->setStyleSheet(QString());
         return false;
     }
 
     int searchMode = ui->modeComboBox->currentIndex();
 
-    QFlags<QTextDocument::FindFlag> options = searchDown ?
-                                              QTextDocument::FindFlag(0)
-                                                         : QTextDocument::FindBackward;
+    QFlags<QTextDocument::FindFlag> options =
+        searchDown ? QTextDocument::FindFlag(0) : QTextDocument::FindBackward;
     if (searchMode == WholeWordsMode) {
         options |= QTextDocument::FindWholeWords;
     }
@@ -228,23 +223,27 @@ bool QTextEditSearchWidget::doSearch(bool searchDown, bool allowRestartAtTop) {
 
     bool found;
     if (searchMode == RegularExpressionMode) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 13, 0))
+        found = _textEdit->find(QRegularExpression(text), options);
+#else
         found = _textEdit->find(QRegExp(text), options);
+#endif
     } else {
         found = _textEdit->find(text, options);
     }
 
     // start at the top (or bottom) if not found
     if (!found && allowRestartAtTop) {
-        _textEdit->moveCursor(
-                searchDown ? QTextCursor::Start : QTextCursor::End);
+        _textEdit->moveCursor(searchDown ? QTextCursor::Start
+                                         : QTextCursor::End);
         found = _textEdit->find(text, options);
     }
 
     QRect rect = _textEdit->cursorRect();
     QMargins margins = _textEdit->layout()->contentsMargins();
     int searchWidgetHotArea = _textEdit->height() - this->height();
-    int marginBottom = (rect.y() > searchWidgetHotArea) ? (this->height() + 10)
-                                                        : 0;
+    int marginBottom =
+        (rect.y() > searchWidgetHotArea) ? (this->height() + 10) : 0;
 
     // move the search box a bit up if we would block the search result
     if (margins.bottom() != marginBottom) {
@@ -253,17 +252,18 @@ bool QTextEditSearchWidget::doSearch(bool searchDown, bool allowRestartAtTop) {
     }
 
     // add a background color according if we found the text or not
-    QString colorCode = found ? "#D5FAE2" : "#FAE9EB";
+    QString colorCode =
+        found ? QStringLiteral("#D5FAE2") : QStringLiteral("#FAE9EB");
 
     if (_darkMode) {
-        colorCode = found ? "#135a13" : "#8d2b36";
+        colorCode =
+            found ? QStringLiteral("#135a13") : QStringLiteral("#8d2b36");
     }
 
-    ui->searchLineEdit->setStyleSheet("* { background: " + colorCode + "; }");
+    ui->searchLineEdit->setStyleSheet(QStringLiteral("* { background: ") +
+                                      colorCode + QStringLiteral("; }"));
 
     return found;
 }
 
-void QTextEditSearchWidget::setDarkMode(bool enabled) {
-    _darkMode = enabled;
-}
+void QTextEditSearchWidget::setDarkMode(bool enabled) { _darkMode = enabled; }
