@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -12,12 +12,11 @@
  */
 
 #include "scriptlistwidget.h"
+
 #include <entities/script.h>
 #include <services/scriptingservice.h>
 
-ScriptListWidget::ScriptListWidget(QWidget *parent) {
-    Q_UNUSED(parent);
-}
+ScriptListWidget::ScriptListWidget(QWidget *parent) { Q_UNUSED(parent); }
 
 void ScriptListWidget::dropEvent(QDropEvent *e) {
     // finish the move event
