@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 Patrizio Bekerle -- http://www.bekerle.com
+ * Copyright (c) 2014-2021 Patrizio Bekerle -- <patrizio@bekerle.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,14 +13,13 @@
 
 #pragma once
 
-#include <QListWidget>
 #include <QDropEvent>
+#include <QListWidget>
 
-class ScriptListWidget : public QListWidget
-{
-public:
+class ScriptListWidget : public QListWidget {
+   public:
     explicit ScriptListWidget(QWidget *parent = Q_NULLPTR);
 
-protected:
+   protected:
     void dropEvent(QDropEvent *e);
 };
